var Case = {}

/** the name of the form (set when the BODY loads) */
Case.FORM_NAME = null;
Case.OBJECT_TYPE = null;
Case.KEY = null;
Case.ID = null;
Case.EDITABLE = false;
Case.REFERRER = null;

Case.getForm = function() {
   return document.getElementById(Case.FORM_NAME);
}

Case.submitForm = function(valueMap)
{
   FormUtil.submitForm(Case.getForm(), valueMap);
}

Case.save = function(form)
{
   if (!form)
   {
      form = Case.getForm();
   }
   App.protectPage();   
   Case.handleDefaultSubmit(form);
   form.submit();
}

Case.saveNew = function()
{
   var form = Case.getForm();
   Case.handleNewDefaultSubmit(form);
   form.submit();
}

Case.handleDefaultSubmit = function(form)
{
   FormUtil.updateForm(form, {command: "save"});
}

Case.handleNewDefaultSubmit = function(form)
{
   form.target = "_top";
   var formValueMap = {command: "save", isNewEntity: "true"};
   FormUtil.updateForm(form, formValueMap);
}

Case.comments = function() {
   CaseCommon.comments(Case.OBJECT_TYPE, Case.KEY, Case.ID);
}

Case.attachments = function() {
   CaseCommon.attachments(Case.OBJECT_TYPE, Case.KEY, Case.ID);
}

Case.cancelNew = function() {
   if (window.parent && window.parent.Dialog && window.parent.Dialog.activeDialog)
   {
      window.parent.Dialog.activeDialog.hide();
      window.parent.App.unprotectPage();
   }
   else
   {
      window.location = Global.CONTEXT_PATH + "/CaseSearch.do";
   }
}

Case.handleReassignDefaultSubmit = function(form)
{
   FormUtil.updateForm(form, {command :"reassign"});
}

Case.reassignSubmit = function(form)
{
   var form = Case.getForm();
   Case.handleReassignDefaultSubmit(form);
   form.submit();
}

Case.reassignCancel = function()
{
   window.parent.Dialog.activeDialog.hide();
}

Case.closeReassignDialog = function()
{
   if (window.parent.Case !== undefined)
   {
      window.parent.Case.submitForm();
   }
   else if (window.parent.Search)
   {
      window.parent.Search.refresh();
   }
}

/**
 * This function is called when the page loads.
 */
Case.handleOnLoad = function()
{
   var onload = BrowserUtil.getRequestParameter("onload");
   App.addBreadcrumb(Case.REFERRER);
   
   if (!onload || App.HAS_ERRORS)
   {
      return;
   }
   
   if (onload == "newParty")
   {
      Case.showNewPartyDialog(Case.UI_CONTEXT_ID);
   }
   
   if (onload == "newReport")
   {
      Case.showNewReportDialog();
   }
}

/**
 * This method is invoked to open a different URL. If changes have been
 * made to the current page then a "Save Changes" confirmation dialog is
 * shown before redirecting.
 */
Case.redirect = function(redirectURL)
{
   var args = {redirectURL: redirectURL};
   SaveChangesConfirmation.confirmSaveChanges(
         Case.saveChangesConfirmationCallback, args);
}

Case.logoff = function()
{
   Case.redirect("Logoff");
}

Case.saveChangesConfirmationCallback = function(saveChangesConfirmation)
{
   App.protectPage();
   
   var resultCode = saveChangesConfirmation.resultCode;
   
   if (resultCode == SaveChangesConfirmation.ResultCode.YES)
   {
      var separator = "?";
      if (saveChangesConfirmation.args.redirectURL.indexOf("?") > -1)
      {
         separator = "&";
      }
      var redirectURL = saveChangesConfirmation.args.redirectURL + separator + "caseSaved=" + Case.KEY;
      
      /* save the case but provide a redirect URL */
      var form = Case.getForm();
      FormUtil.updateForm(form, {redirectURL: redirectURL});
      Case.save(form);
   }
   else if ((resultCode == SaveChangesConfirmation.ResultCode.NO) ||
            (resultCode == SaveChangesConfirmation.ResultCode.NOT_DIRTY))
   {
      /* user does not want to save or the page is not dirty */
      window.location = saveChangesConfirmation.args.redirectURL;
   }
}

Case.newParty = function(uiContextID, caseKey, fromModal)
{
   Case.KEY = caseKey;
   var args = {uiContextID: uiContextID, fromModal: fromModal};
   if (fromModal)
   {
      parent.SaveChangesConfirmation.confirmSaveChanges(Case.newPartySaveChangesConfirmationCallback, args);
   }
   else 
   {
      SaveChangesConfirmation.confirmSaveChanges(Case.newPartySaveChangesConfirmationCallback, args);
   }
}

Case.newPartySaveChangesConfirmationCallback = function(saveChangesConfirmation)
{
   App.protectPage();

   var resultCode = saveChangesConfirmation.resultCode;
   var fromModal = saveChangesConfirmation.args.fromModal;
   
   if (resultCode == SaveChangesConfirmation.ResultCode.YES)
   {
      /* set parameters that will cause new case dialog to appear after save */
      if (fromModal)
      {
         var form = parent.Case.getForm();
         parent.FormUtil.updateForm(form, {onload: "newParty"});
         
         // save the case
         parent.Case.save(form);
      }
      else
      {
         var form = Case.getForm();
         FormUtil.updateForm(form, {onload: "newParty"});
         
         // save the case
         Case.save(form);
      }
   }
   else if ((resultCode == SaveChangesConfirmation.ResultCode.NO) ||
            (resultCode == SaveChangesConfirmation.ResultCode.NOT_DIRTY))
   {
      Case.showNewPartyDialog(saveChangesConfirmation.args.uiContextID, fromModal);
   }
}

Case.showNewPartyDialog = function(uiContextID, fromModal)
{
   var url = Global.CONTEXT_PATH + "/Party.do?command=newEntity&forCaseKey=" + Case.KEY + "&parentUIContextID=" + uiContextID;
   if (fromModal)
   {
      IFrameDialog.loadExistingWindow({
         url: url,
         title: AppProperties["caseIncident.newParty.title.txt"]
      });
   } 
   else 
   {
      IFrameDialog.show({
         url: url,
         width: 750, height: 450,
         title: AppProperties["caseIncident.newParty.title.txt"]});
   }
}

Case.showNewReportDialog = function()
{
   var url = Global.CONTEXT_PATH + "/Report.do?command=newEntity";
   IFrameDialog.show({
      url: url,
      width: 500, height: 200,
      title: AppProperties["newReport.title.txt"]});
}


Case.print = function()
{
   CaseCommon.print(Case.KEY);
}

Case.printSave = function()
{
   CaseCommon.printSave(Case.KEY, Case.ID);
}
