var Incident = {};

/** the name of the form (set when the BODY loads) */
Incident.FORM_NAME = null;
Incident.OBJECT_TYPE = null;
Incident.KEY = null;
Incident.ID = null;
Incident.EDITABLE = false;
Incident.UI_CONTEXT_ID = null;
Incident.REFERRER = null;

Incident.getForm = function()
{
   return document.getElementById(Incident.FORM_NAME);
}

Incident.submitForm = function(valueMap)
{
   FormUtil.submitForm(Incident.getForm(), valueMap);
}

Incident.save = function(form)
{
   if (!form)
   {
      form = Incident.getForm();
   }
   App.protectPage();
   Incident.handleDefaultSubmit(form);
   form.submit();
}

Incident.saveNew = function()
{
   var form = Incident.getForm();
   Incident.handleNewDefaultSubmit(form);
   form.submit();
}

Incident.handleDefaultSubmit = function(form)
{
   FormUtil.updateForm(form, {command: "save"});
}

Incident.handleNewDefaultSubmit = function(form)
{
   form.target = "_top";
   FormUtil.updateForm(form, {command: "save", isNewEntity: "true"});
}

Incident.relatedCases = function()
{
   var form = Incident.getForm();
   
   var url = Global.CONTEXT_PATH + "/AddIncidentToCase.do" +
      "?key=" + form.elements["key"].value +
      "&uiContextId=" + form.elements["uiContextId"].value +
      "&windowLayout=" + WindowLayout.MODAL_DIALOG;
   var title = AppProperties["incident.relatedCases.title.txt"] + 
      "&nbsp;&#149;&nbsp;" + 
      AppProperties["incident.title.txt"] + "&nbsp;" + Incident.ID
   IFrameDialog.show({
      url: url,
      width: 800, height: 500,
      title: title});
}

Incident.refreshCaseLink = function(elementID)
{
   var el = document.getElementById(elementID);
   if (el && el != null)
   {
      PleaseWait.show(el);
         
      IncidentCaseLinkComponentService.refreshLink(
               Incident.UI_CONTEXT_ID, 
               function(html) {
                  el.innerHTML = html;
               }
      );
   }
   
   if (window.SaveChangesConfirmation)
   {
      SaveChangesConfirmation.setPageDirty();
   }
}

Incident.deleteIncident = function()
{
   Incident.submitForm({command: "deleteIncident"});
}

Incident.comments = function()
{
   Comments.showDialog(Incident.KEY, Incident.OBJECT_TYPE, AppProperties["incident.title.txt"] + "&nbsp;" + Incident.ID);
}

Incident.attachments = function()
{
   var url = Global.CONTEXT_PATH + "/Attachments.do?command=display&key=" + Incident.KEY + "&objType=" + Incident.OBJECT_TYPE;
   var title =
	   AppProperties["attachments.title.txt"] +
	   "&nbsp;&#149;&nbsp;" +
	   AppProperties["incident.title.txt"] +
	   "&nbsp;" +
	   Incident.ID;
   IFrameDialog.show({url: url, title: title});
}

Incident.cancelNew = function()
{
   if (window.parent && window.parent.Dialog && window.parent.Dialog.activeDialog)
   {
      window.parent.Dialog.activeDialog.hide();
      window.parent.App.unprotectPage();
   }
   else
   {
      window.location = Global.CONTEXT_PATH + "/IncidentSearch.do";
   }
}

Incident.handleFormOnSubmit = function(form)
{
   return true;
}

Incident.newCase = function()
{
   SaveChangesConfirmation.confirmSaveChanges(
         Incident.newCaseSaveChangesConfirmationCallback);
}

Incident.showNewCaseDialog = function(key)
{
   var url = Global.CONTEXT_PATH + "/Case.do?command=newEntity&forIncidentKey=" + key;
   IFrameDialog.show({
      url: url,
      width: 600, height: 400,
      title: AppProperties["incident.newCase.title.txt"]});
}

Incident.newCaseSaveChangesConfirmationCallback = function(saveChangesConfirmation)
{
   App.protectPage();
   
   var resultCode = saveChangesConfirmation.resultCode;
   
   if (resultCode == SaveChangesConfirmation.ResultCode.YES)
   {
      /* set parameters that will cause new case dialog to appear after save */
      var form = Incident.getForm();
      FormUtil.updateForm(form, {onload: "newCase"});
      
      /* save the incident */
      Incident.save(form);
   }
   else if ((resultCode == SaveChangesConfirmation.ResultCode.NO) ||
            (resultCode == SaveChangesConfirmation.ResultCode.NOT_DIRTY))
   {
      Incident.showNewCaseDialog(Incident.KEY);
   }
}

Incident.logoff = function()
{
   Incident.redirect("Logoff");
}

Incident.redirect = function(redirectURL)
{
   var args = {redirectURL: redirectURL};
   SaveChangesConfirmation.confirmSaveChanges(
         Incident.saveChangesConfirmationCallback, args);
}

Incident.saveChangesConfirmationCallback = function(saveChangesConfirmation)
{
   App.protectPage();
   
   var resultCode = saveChangesConfirmation.resultCode;
   
   if (resultCode == SaveChangesConfirmation.ResultCode.YES)
   {
      var redirectURL = 
            saveChangesConfirmation.args.redirectURL + "&incidentSaved=" + Incident.KEY;
      
      /* save the incident but provide a redirect URL */
      var form = Incident.getForm();
      FormUtil.updateForm(form, {redirectURL: redirectURL});
      Incident.save(form);
   }
   else if ((resultCode == SaveChangesConfirmation.ResultCode.NO) ||
            (resultCode == SaveChangesConfirmation.ResultCode.NOT_DIRTY))
   {
      /* user does not want to save or the page is not dirty */
      window.location = saveChangesConfirmation.args.redirectURL;
   }
}

Incident.handleOnLoad = function()
{
   var onload = BrowserUtil.getRequestParameter("onload");
   
   // register breadcrumb
   App.addBreadcrumb(Incident.REFERRER);
   
   if (!onload || App.HAS_ERRORS)
   {
      return;
   }
   
   if (onload == "newCase")
   {
      Incident.showNewCaseDialog(Incident.KEY);
   }
   
   if (onload == "newParty")
   {
      Incident.showNewPartyDialog(Incident.UI_CONTEXT_ID);
   }
   
   if (onload == "newReport")
   {
      Incident.showNewReportDialog();
   }
}

Incident.newParty = function(uiContextId, incidentKey, fromModal)
{
   Incident.KEY = incidentKey;
   var args = {uiContextId: uiContextId, fromModal: fromModal};
   if (fromModal)
   {
      parent.SaveChangesConfirmation.confirmSaveChanges(Incident.newPartySaveChangesConfirmationCallback, args);
   }
   else 
   {
      SaveChangesConfirmation.confirmSaveChanges(Incident.newPartySaveChangesConfirmationCallback, args);
   }
}

Incident.newPartySaveChangesConfirmationCallback = function(saveChangesConfirmation)
{
   App.protectPage();
   
   var resultCode = saveChangesConfirmation.resultCode;
   var fromModal = saveChangesConfirmation.args.fromModal;
   
   if (resultCode == SaveChangesConfirmation.ResultCode.YES)
   {
      /* set parameters that will cause new party dialog to appear after save */
      if (fromModal)
      {
         var form = parent.Incident.getForm();
         parent.FormUtil.updateForm(form, {onload: "newParty"});
         
         // save the incident
         parent.Incident.save(form);
      }
      else
      {
         var form = Incident.getForm();
         FormUtil.updateForm(form, {onload: "newParty"});
         
         // save the incident
         Incident.save(form);
      }
   }
   else if ((resultCode == SaveChangesConfirmation.ResultCode.NO) ||
            (resultCode == SaveChangesConfirmation.ResultCode.NOT_DIRTY))
   {
      Incident.showNewPartyDialog(saveChangesConfirmation.args.uiContextId, fromModal);
   }
}

Incident.showNewPartyDialog = function(uiContextId, fromModal)
{
   var url = Global.CONTEXT_PATH + "/Party.do?command=newEntity&forIncidentKey=" + Incident.KEY + "&parentUIContextID=" + uiContextId;
   if (fromModal)
   {
      IFrameDialog.loadExistingWindow({
         url: url,
         title: AppProperties["caseIncident.newParty.title.txt"]
      });
   } 
   else 
   {
      IFrameDialog.show({
         url: url,
         width: 750, height: 450,
         title: AppProperties["caseIncident.newParty.title.txt"]});
   }
}

Incident.showNewReportDialog = function()
{
   var url = Global.CONTEXT_PATH + "/Report.do?command=newEntity";
   IFrameDialog.show({
      url: url,
      width: 500, height: 200,
      title: AppProperties["newReport.title.txt"]});
}

