/*******************************************************************************/
/* Load FINCEN New CTR configuration data                                      */
/* To test one the code without loading the data, %let ECM_DBUG=Y;             */
/*******************************************************************************/


%macro ecm_loadrr_config_newctr;

/*****************************************************************************************/
/* Define RR and EFILE configuration data                                                */
/*****************************************************************************************/

%if &ecm_debug = N %then
%do;

proc sql noprint;
   %let efile_fincen_defined=N;
   select distinct 'Y' into :efile_fincen_defined 
   from ecm_db.ref_table_value 
   where value_cd='FINCEN' and ref_table_nm='RT_EFILE_CATEGORY';
   %if &efile_fincen_defined=N %then
   %do;
        insert into ecm_db.ref_table_value values ('RT_EFILE_TYPE', 'US', 'US', null, null, 0);
        insert into ecm_db.ref_table_value values ('RT_EFILE_CATEGORY', 'FINCEN', 'Financial Crimes Enforcement Network', null, null, 0);
   %end;


   insert into ecm_db.efile_config values (&efile_config_seq_no, 'US', 'FINCEN', 'NEWCTR', 'efile-fincen-new-01.xml'
                                         , 'FINCEN', 'NEWCTR'); 
   insert into ecm_db.ref_table_value values ('RT_EFILE_SUBCATEGORY', 'NEWCTR', 
                       'New CTR', 'RT_EFILE_CATEGORY', 'FINCEN', 0);

   insert into ecm_db.efile_config_x_user_group values (&efile_config_seq_no, 'CASE_FINANCIAL');


   insert into ecm_db.rr_config values (&rr_config_seq_no, 'US', 'FINCEN', 'NEWCTR', 'rr-fincen-ctr-02.xml'
                                         , 'FINCEN', 'NEWCTR',&efile_config_seq_no, 'FINCENReport'); 

   %let rr_fincen_defined=N;
   select distinct 'Y' into :rr_fincen_defined 
   from ecm_db.ref_table_value 
   where value_cd='FINCEN' and ref_table_nm='RT_RR_CATEGORY';
   %if &rr_fincen_defined=N %then
   %do;
        insert into ecm_db.ref_table_value values ('RT_RR_TYPE', 'US', 'US', null, null, 0);
        insert into ecm_db.ref_table_value values ('RT_RR_CATEGORY', 'FINCEN', 'Financial Crimes Enforcement Network', null, null, 0);
   %end;
      
   insert into ecm_db.ref_table_value values ('RT_RR_SUBCATEGORY', 'NEWCTR'
                , 'New CTR', 'RT_RR_CATEGORY', 'FINCEN', 0);
  
   insert into ecm_db.rr_config_x_user_group values (&rr_config_seq_no, 'CASE_FINANCIAL');

  
   %let form_fincen_defined=N;
   select distinct 'Y' into :form_fincen_defined 
   from ecm_db.ref_table_value 
   where value_cd='FINCEN' and ref_table_nm='RT_FORM_AGENCY';
   %if &form_fincen_defined=N %then
   %do;
        insert into ecm_db.ref_table_value values ('RT_FORM_AGENCY', 'FINCEN', 'Financial Crimes Enforcement Network', null, null, 0);
   %end;
   insert into ecm_db.ref_table_value values ('RT_FORM_TYPE', 'NEWCTR', 'New CTR', 'RT_FORM_AGENCY', 'FINCEN', 0); 
 
 
 
  
quit;
%end;
%mend;


%macro ecm_loadrr_udf_def_newctr;

/*******************************************************************************/
/*  Load RR UDF fields                                                         */
/*******************************************************************************/

data rr_udf_def_newctr;
if 0 then set ecm_db.rr_udf_def;

   
     infile "&form_path&slash.rr_udf_def_newctr.csv"  
             dsd lrecl=32764 truncover firstobs=2  delimiter=',' ;            
     input udf_table_nm $
           udf_nm $
           udf_type_nm $
           max_char_cnt    
           udf_desc $
                  
    ;
run;
%if &sysrc <= 4 and &ecm_debug=N %then
%do;
    proc sql noprint;
          delete from rr_udf_def_newctr
          where strip(udf_table_nm)||'|'||strip(udf_nm) in
          (select distinct strip(udf_table_nm)||'|'||strip(udf_nm) 
                  from ecm_db.rr_udf_def
          )
          ;
    proc append base=ecm_db.rr_udf_def data=rr_udf_def_newctr force;
    run;
%end;

%mend;

%macro ecm_loadrr_ref_newctr;

/******************************************************************************/
/*  Load reference table values                                               */
/******************************************************************************/

data ref_table_value_newctr;
 infile  "&form_path&slash.newctr-efile_field_config_ref.csv"  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
   length tmp_word source_ref_list$ 32767;
   if 0 then set ecm_db.form_efile_field_config;
   if 0 then set ecm_db.Ref_table_value;
   input 
           form_efile_record_id $
           target_field_position $
           target_field_nm $
           target_field_length_no
           target_field_desc $
           source_field_nm $
           source_ref_list $                
    ;
    
    keep  ref_table_nm value_cd value_desc parent_ref_table_nm parent_value_cd display_order_no;
   
    
    tmp_word='';
    tmp_i=1;
    do until (scan(source_ref_list,tmp_i,'|')='');
       tmp_word=left(scan(source_ref_list,tmp_i,'|'));
       ref_table_nm='X_RT_'||substr(source_field_nm,3,length(source_field_nm)-5);
       value_cd=substr(tmp_word,1,1);
       value_desc=left(substr(tmp_word,2));
       display_order_no=tmp_i;
       output;
       tmp_i+1;
    end;
    
 
run;

%if &sysrc <= 4 and &ecm_debug=N %then
%do;
     proc sql noprint;
          delete from ref_table_value_newctr
          where strip(ref_table_nm)||'|'||strip(value_cd) in
          (select distinct strip(ref_table_nm)||'|'||strip(value_cd) 
                  from ecm_db.ref_table_value
          )
          ;
    proc append base=ecm_db.ref_table_value data=ref_table_value_newctr   force;
    run;
%end;


%mend;

%macro ecm_loadrr_form_config_newctr; 
%if &ecm_debug = N %then
%do;
proc sql;
   insert into ecm_db.form_config values (&form_config_rk,
                                        'FINCEN',
                                        'NEWCTR'
                                        'US',
                                       '01JUL2012:00:00:00'dt,null,
                                       'New CTR',
                                       'application/pdf','newctr',
                                       'ecmrr_prvw_fincen_newctr_driver',
                                       'ecmrr_prvw_fincen_newctr_data',
                                       'fincen-newctr-v1',
                                       'ecmrr_efile_fincen_newctr_driver',
                                       'ecmrr_efile_fincen_newctr_data',
                                       700,
                                        null,null,null,null,'0');
%end;

%mend;


%macro ecm_loadrr_efile_newctr;
/**********************************************************/
/* Load record level efile configuration data             */
/**********************************************************/

/* Record level configuration data */

data efile_record_config_newctr;
if 0 then set ecm_db.form_efile_record_config;

   
     infile "&form_path&slash.newctr-efile_record_config.csv"  
             dsd lrecl=32764 truncover firstobs=2  delimiter=',' ;
             retain form_config_rk &form_config_rk;
             retain form_efile_record_seq_no;
     input form_efile_record_id $
           form_efile_record_desc $
           record_sort_order_no
           record_length_no 
           source_table_nm $
           page_by_field_nm $
              
    ;
    form_config_rk=&form_config_rk;
    if form_efile_record_id > '' then 
    do;     
        form_efile_record_seq_no+1;
        output;
    end;

run;
 
 
/* Field level configuration data */


data efile_field_config_newctr;
if 0 then set ecm_db.form_efile_field_config;

     length target_field_position $ 100;
     infile  "&form_path&slash.newctr-efile_field_config.csv"  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
     
     input 
           form_efile_record_id $
           target_field_position $
           target_field_nm $
           target_field_length_no
           target_field_desc $
           source_field_nm $
           source_field_num_flg $ 
           source_field_exp $
           sas_format_nm $
          
    ;

    form_config_rk=202;
    form_efile_field_seq_no=_n_;
    target_field_start_pos_no=input(scan(target_field_position,1,'-'),best.);
    target_field_end_pos_no=target_field_start_pos_no + target_field_length_no-1;
    if form_efile_record_id='' then  delete;
    
    drop  target_field_position ;
    drop form_efile_record_seq_no; /* to be assigned in the next step */
     
run;
proc sql noprint;
     create table form_efile_field_config_newctr as
     select a.*, b.form_efile_record_seq_no
     from efile_field_config_newctr as a,
          efile_record_config_newctr as b
     where a.form_efile_record_id=b.form_efile_record_id
     order by form_efile_field_seq_no;
quit;

%if &sysrc <= 4 and &ecm_debug=N %then
%do;
    proc sql;
     delete 
     from ecm_db.form_efile_field_config
     where form_config_rk=&form_config_rk;

     delete 
     from ecm_db.form_efile_record_config
     where form_config_rk=&form_config_rk;
   quit;

    proc append base=ecm_db.form_efile_record_config data=efile_record_config_newctr force; 
    run;

    proc append base=ecm_db.form_efile_field_config 
                data=form_efile_field_config_newctr (drop=form_efile_record_id)
                force; 
    run;
%end;

%mend;


%macro ecm_loadrr_prvw_newctr;
/* Section level configuration data */

/* Section level configuration data */
data newctr_preview_section_config;
if 0 then set ecm_db.form_preview_section_config;

   
     infile "&form_path&slash.newctr-preview_section_config.csv" 
             dsd lrecl=32764 truncover firstobs=2  delimiter=',' ;
     input form_config_rk
           form_preview_section_seq_no
           form_preview_section_id $
           section_desc $
           section_order_no 
           section_file_suffix $
           source_table_nm $
    ;
    form_config_rk=&form_config_rk;
run;

 
/* Field level configuration data */

data newctr_preview_field_config;
if 0 then set ecm_db.form_preview_field_config;

   
     infile  "&form_path&slash.newctr-preview_field_config.csv"  
             dsd lrecl=32764 truncover firstobs=2 delimiter=',' ;
     
     input form_config_rk 
           form_preview_section_seq_no
           form_preview_field_seq_no :best. /* make sure decimal numbers are read correctly */
           source_field_nm $
           source_field_num_flg $
           source_field_exp $
           target_field_nm $
           target_field_type_cd $
           target_field_type_parm_list $
     ; 
     form_config_rk=&form_config_rk;    
    
run;

%if &sysrc <= 4 and &ecm_debug=N %then
%do;
   proc sql;
     delete 
    from ecm_db.form_preview_field_config
     where form_config_rk=&form_config_rk;

     delete 
     from ecm_db.form_preview_section_config
     where form_config_rk=&form_config_rk;
   quit;

proc append base=ecm_db.form_preview_section_config data=newctr_preview_section_config; 
run;
proc append base=ecm_db.form_preview_field_config data=newctr_preview_field_config; 
run;
%end;

%mend;

/* Change ecm_debug to Y for testing */
%let ecm_debug=N;
/* Adjust the sequence number if it has been used */
%let rr_config_seq_no=202;
%let efile_config_seq_no=202;
%let form_config_rk=202;
%let form_path=&ecm_config_path&slash.Source&slash.form_template;


%ecm_loadrr_config_newctr;    /* load rr and efile config data */
%ecm_loadrr_udf_def_newctr;   /* load rr UDF fields            */
%ecm_loadrr_ref_newctr;       /* load reference values         */

/* %ecm_loadrr_ref_naics; */ /* load NAICS codes              */
%ecm_loadrr_form_config_newctr;   /* load FORM config data         */
%ecm_loadrr_efile_newctr;   /* load efile record level definition */ 

%ecmrr_efile_pgm_gen( form_config_rk=&form_config_rk); 
%ecmrr_efile_makedir(form_config_rk=&form_config_rk);


%ecm_loadrr_prvw_newctr;
%ecmrr_fdf_pgm_gen;
%let form_config_rk=202;
