
/***********************************************************************************/
/* Copyright (c) 2009-2012, SAS Institute Inc., Cary, NC, USA, All Rights Reserved */
/*                                                                                 */
/* NAME:          ecm_get_field_value                                              */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       Pull the field values if the use has access to it                */
/* PARAMETERS:    uesrid: Input user ID                                            */
/*                datatype: CASE, PARTY, INCIDENT                                  */
/*                field_nm: name of the field to be pulled                         */ 
/*                subset_dsn: tables with surrogate key of the data type object    */
/*                out_dsn:  output table name                                      */
/* NOTE:          The output table contains only the values that the user can see  */
/***********************************************************************************/
 
%macro ecm_get_field_value (userid=,field_nm=,datatype=,subset_dsn=, out_dsn=out_dsn)
           / des='get values of the fields that the user can see ';
   %put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;
 
%let abortRC=0;
 %if &userID= %then
%do;
   %let abortRC=1;
   %put %sysfunc(sasmsg(&smdds,GEN_PARM_MISSING_ERROR,NOQUOTE,userID)) ;
   %goto MEXIT;
%end;
%let datatype=%upcase(&datatype);
%if not (&datatype = CASE or &datatype =PARTY or &datatype = INCIDENT or &datatype=RR) %then
%do;
   %let abortRC=1;
   %put %sysfunc(sasmsg(&smdds,GEN_PARM_INVALID_ERROR,NOQUOTE,DATATYPE,"CASE" "PARTY" "INCIDENT" "RR")) ;
   %goto MEXIT;
%end;

%let field_nm=%upcase(&field_nm);
%let field_exist=0;
%if %substr(&field_nm,1,2)=%str(X_) %then
%do;
   %let udf_type_nm=;
    %let udf_type_str=;
    /* exist in UDF */
	proc sql noprint;
         select 1,
               udf_type_nm, 
               case
                  when (udf_type_nm in ('VARCHAR' 'CHAR' 'BOOLEAN')) then 'CHAR'
                  when (udf_type_nm in ('INTEGER' 'FLOAT' 'DOUBLE' 'BIGINT' )) then 'NUM'
                  when (udf_type_nm in ('DATE' 'TIMESTAMP')) then 'DATE'
                  when (udf_type_nm = 'LNGVARCHAR' ) then 'LGCHR'
                  else 'CHAR'
               end
               into
               :field_exist,
               :udf_type_nm, 
               :udf_type_str
               from ecm_db.&datatype._udf_def
               where upcase(udf_table_nm)=upcase("&datatype") and upcase(udf_nm)=upcase("&field_nm")
     ;
      %let udf_type_str=%trim(&udf_type_str);
%end; 
%else 
%do;
   /* exist in LIVE */
   proc sql noprint;
         select 2, format  
                into 
                :field_exist, :field_format 
         from dictionary.columns
         where libname='ECM_DB' and memname="&DATATYPE._LIVE" and upcase(name)=upcase("&field_nm")
         ;
%end;    
      
%if &field_exist=0 %then
%do;
   %let abortRC=1;
   %put %sysfunc(sasmsg(&smdds,GEN_FIELD_INVALID_ERROR,NOQUOTE,&field_nm)) ;
   %goto MEXIT;
%end;

%if &subset_dsn= %then
%do;
   %let abortRC=1;
   %put %sysfunc(sasmsg(&smdds,GEN_PARM_MISSING_ERROR,NOQUOTE,SUBSET_DSN)) ;
   %goto MEXIT;
%end;

%let user_group_list=;
%ecm_get_usergroup(userID=&userID,outMacVar=user_group_list); 
%if &user_group_list = %then %let user_group_list='';
  
proc sql noprint;
         create table &out_dsn as 
%if &field_exist=2 %then
%do;
	
         select distinct
                b.&datatype._rk,
                b.&field_nm as field_value,
                put(b.&field_nm,&field_format) as field_formatted_value        
         from  &subset_dsn as a, 
               ecm_db.&datatype._live as b,
               ecm_db.&datatype._x_user_group as c 
		 where a.&datatype._rk=b.&datatype._rk and
               a.&datatype._rk=c.&datatype._rk and
	           c.user_group_nm in (&user_group_list)
		 ;
	
%end;
%else
%do;
   
	 
         select distinct  
                b.&datatype._rk, 
                d.udf_value as field_value,
         %if &udf_type_str = NUM %then
         %do;
              put(d.udf_value,best.)  
         %end;
         %else %if &udf_type_nm=TIMESTAMP %then
         %do;
              put(datepart(d.udf_value),yymmddd10.)||'T'||put(timepart(d.udf_value),time8.)  
         %end;
         %else %if &udf_type_nm=DATE %then
         %do;
              put(datepart(d.udf_value),yymmddd10.)  
         %end;
         %else
         %do; 
              d.udf_value 
         %end;
              as field_formatted_value 
         from  &subset_dsn as a,                 
               ecm_db.&datatype._live as b,
               ecm_db.&datatype._x_user_group as c,
               ecm_db.&datatype._udf_&udf_type_str._value as d
                
             
		 where a.&datatype._rk=b.&datatype._rk and
               a.&datatype._rk=c.&datatype._rk and
	           c.user_group_nm in (&user_group_list) and
               b.&datatype._rk=d.&datatype._rk and
               b.valid_from_dttm=d.valid_from_dttm and
               d.udf_table_nm="&datatype" and
               d.udf_nm="&field_nm"
		 ;
 
%end;
create unique index &datatype._rk on &out_dsn; 
quit;

%if &syserr > 4 %then 
%do;
   %let abortRC=1;
   %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
   %goto MEXIT;
%end;

 
 

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;

%MEXIT:


%mend;

/*
%ecm_get_field_value(userid=admin,field_nm=party_full_nm,datatype=PARTY,subset_dsn=party_f, out_dsn=out_party);

%ecm_get_field_value(userid=admin,field_nm=x_birth_dt,datatype=PARTY,subset_dsn=party_f, out_dsn=out_party);

*/
