
/***********************************************************************************/
/* Copyright (c) 2012, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecm_ws_writeXML                                                  */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       wrap around name/value xml tags with ECM create/edit web service */
/*                required tags.                                                   */
/* PARAMETERS:    indsn: input data set containing name and value tag              */
/*                       which is the body of the create or edit request           */
/*                outfref: fname of the output response file                       */
/*                countrycode: country code to be passed to the web service        */
/*                languageCode: language code to be passed to the web service      */
/*                sourceSystemCode: source system code to be passed to the web     */
/*                                  service                                        */
/*                testmodeYN: Y for mode="test_mode"                               */
/*                operation= Create (only)  for ECM create request                 */
/* NOTE:                                                                           */
/***********************************************************************************/

%macro ecm_ws_writeXML(indsn=
                      ,outfref=request
                      ,countrycode=US
                      ,languageCode=en
                      ,sourceSystemCode=SASECM
                      ,testmodeYN=N
                      ,force_update=Y
                      ,operation=Create);

 %put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ; 


%local operation_tag;
%let operation_tag=%sysfunc(propcase(&operation));

data _null_;
file &outfref;
set &indsn end=eof;
length tmp_stmt $32760;

if _n_=1 then link INIT;
put stmt;
if eof then link TERM;
return;
INIT:
/* Commenting out soapenv envelope */
/* It is not needed for 9.3        */
/*
put '<soapenv:Envelope';
put ' xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"';
put ' xmlns:xsd="http://www.w3.org/2001/XMLSchema"';
put ' xmlns:soapenv="http://schemas.xmlsoap.org/soap/envelope/"';
put ' xmlns:ecm="http://sas.com/solutions/casemgmt/webservice">';


put;   
put '<soapenv:HeaderBlock>';
put '<Action xmlns="http://schemas.xmlsoap.org/ws/2004/08/addressing">http://sas.com/solutions/casemgmt/webservice/CaseManagementServiceInterface/create</Action>';
put '</soapenv:HeaderBlock>';
put;
put '<soapenv:Body>';
*/
tmp_stmt="<ecm:&operation_tag.Request ";
tmp_stmt=strip(tmp_stmt)||' xmlns:ecm="http://sas.com/solutions/casemgmt/webservice"';
%if &testmodeYN=Y %then 
%do;
  tmp_stmt=strip(tmp_stmt)||' mode="test_mode" ';
%end;

%if &force_update=Y %then
%do;
  tmp_stmt=strip(tmp_stmt)||' lockHandlingMode="update_locked_objects"'; 
%end;
  tmp_stmt=strip(tmp_stmt)||' countryCode="'||"&countryCode"||'"';
  tmp_stmt=strip(tmp_stmt)||' languageCode="'||"&languageCode"||'"'; 
  tmp_stmt=strip(tmp_stmt)||' sourceSystemCode="'||"&sourceSystemCode"||'">';
 
put tmp_stmt;
return;

TERM:

put "</ecm:&operation_tag.Request>";
/*
put '</soapenv:Body>';
put '</soapenv:Envelope>';
*/
return;

run;


%if &syserr > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;

%mExit:

 %put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ; 


%mend;

/*
%ecm_ws_writeXMl(indsn=efile_ws,outfref=request);
*/
