
/***********************************************************************************/
/* Copyright (c) 2012, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_efile_fincen_trnsmttr_detail                               */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       Extract transmitter information                                  */
/* PARAMETERS:    efile_rk=efile key                                               */
/*                outdsn: output table name                                        */
/*                form_type_cd: form type                                          */ 
/* NOTE:          This program is assuming all transmitter fields are udf fields   */
/*                and udf type is only char or varchar                             */ 
/*                if efile_rk is not empty, transmitter info will pull from        */
/*                the efile record                                                 */
/*                Otherwise %ecmrr_efile_fincen_trnsmttr_var will be called to     */
/*                get the data.                                                    */ 
/***********************************************************************************/

%macro ecmrr_efile_fincen_trnsmttr_rec(efile_rk, outdsn=x_transmitter,form_type_cd=);


%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;


data _null_;
    set ecm_db.efile_udf_def end=eof;
    where udf_type_nm in ('VARCHAR' 'CHAR');
    call symput("EFILE_UDF_NM"||strip(put(_n_,best.)),strip(udf_nm));
    call symput("EFILE_UDF_LENGTH"||strip(put(_n_,best.)),put(max_char_cnt,best.));
    if eof then call symput('EFILE_UDF_CNT',put(_n_,best.)); 
run;


%do i=1 %to &efile_udf_cnt;
   %let &&&efile_udf_nm&i=;
%end;


%if &efile_rk= %then
%do;

%ecmrr_efile_fincen_trnsmttr_var(form_type_cd=&form_type_cd);
%end;

%else
%do;
   
   proc sql noprint;
        create table efile_udf_char_value as
        select distinct udf_nm
                        , udf_value
        from ecm_db.efile_udf_char_value as a,
             ecm_db.efile_live as b
        where b.efile_rk=&efile_rk and b.valid_from_dttm=a.valid_from_dttm;

  
   data _null_;
        set efile_udf_char_value;
        call symput(udf_nm,udf_value);
   run;

%end;


data &outdsn;

      %do i=1 %to &efile_udf_cnt;
           length &&&efile_udf_nm&i $ &&&efile_udf_length&i;
           &&&efile_udf_nm&i=symgetc("&&&efile_udf_nm&i");
      %end;
      output;
      
run;

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;



%mend;
