
/***********************************************************************************/
/* Copyright (c) 2012, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_fdf_newctr_driver                                          */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       driver program to generate newctr fdf files                      */
/*                                                                                 */
/* PARAMETERS:                                                                     */
/*                rr_rk: key of the report to populate a fdf file (required)       */
/*                form_config_rk: key of the form (required)                       */
/* NOTE:          the fdf output is saved in the work directory                    */
/*                For testing:                                                     */
/*                To see the fdf in pdf form, copy the .pdf form to the work       */
/*                directory. Then click on the fdf file. Adobe reader is required. */
/***********************************************************************************/
%macro ecmrr_fdf_newctr_driver(rr_rk=
                      ,form_config_rk=                      
                      );
%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

%local last_page_no total_page_no;

%let total_page_no=0;

/* Create section configuration data  */
/* For CTR, there is only one section */
/* That means no nested pages within  */
/* institutions or subjects            */
proc sql noprint;
     create table section_config_rr as
     select a.*, b.preview_file_prefix,
            'Z_RR_SEQ_NO' as by_var  
     from ecm_db.form_preview_section_config as a,
          ecm_db.form_config as b
     where a.form_config_rk=&form_config_rk and
           a.form_config_rk=b.form_config_rk           
     order by section_order_no;
     quit;

/* get total page number */
%let total_page_no=0;
data _null_;

     set section_config_rr end=eof;

     src_dsid=open(source_table_nm);
     src_nobs=attrn(src_dsid,'NOBS');
     total_page_no+src_nobs;
     src_dsid=close(src_dsid);
     if eof then call symput('TOTAL_PAGE_NO',strip(put(total_page_no,best.)));
run;


data page_log;
     length fdf_nm template_nm output_nm $ 1024;
     stop;
run;

%let last_page_no=0;

/* generate the fdf files based on the definition in the section configration file */

%ecmrr_fdf_new_subdriver(form_preview_config_table_nm=section_config_rr
                         ,last_page_no_mvar=last_page_no
                         ,total_page_no=&total_page_no
                         );

 

/* Merge all the fdf files with the correct pdf templates and generate the final pdf */
%ecmrr_fdf_new_merger(page_log_table_nm=page_log);

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;
MEXIT: 
%mend;
 
