
/***********************************************************************************/
/* Copyright (c) 2012, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_efile_fincen_concat_sar_type_cd                            */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:      Concatenate the sar type codes into strings for e-filing          */
/* PARAMETERS:   None                                                              */
/*                                                                                 */
/* NOTE:  This macro is using the output from %ecm_pivot_datatype                  */
/*        It is called by ecmrr_fincen_sar_detail                                  */
/***********************************************************************************/

%macro ecmrr_fincen_concat_sar_type_cd;
     
/*******************************************************************************/
/* Concatenate the following SAR type codes into a string for efiling          */
/* X_SAR_STRUCT_TYPE_CD (7 max) - structuring (item 39) 3A 73                  */
/* X_SAR_TERRORIST_TYPE_CD (2 max) - Terrorist financing (item 30) 3A 130      */
/* X_SAR_FRAUD_TYPE_CD (11 max) - Fraud (item 31) 3A 182                       */
/* X_SAR_CASINO_TYPE_CD (5 max) - Casinos (item 31)  3A 243                    */
/* X_SAR_ML_TYPE_CD (13 max) - Money Laundering (item 33) 3A 298               */
/* X_SAR_ID_TYPE_CD (6 max) - ID (item 34) 3A 361                              */
/* X_SAR_OTHER_TYPE_CD (19 max) - Other Suspicious Activities (Item 35) 3A 417 */
/* X_SAR_INSURANCE_TYPE_CD (7 max) - Insurance (Item 36) 3A 486                */
/* X_SAR_SF_TYPE_CD (5 max) - Securities/Futures/Options (Item 37) 3A 543      */
/* X_SAR_MORTGAGE_TYPE_CD (5 max) - Mortgage Fraud (item 38) 3A 598            */
/* X_SAR_PROD_TYPE_CD (20 max) - Products type(s) involvfed (item 39) 3A 653   */
/* X_SAR_INSTRUMENT_TYPE_CD (10) - Instruments Types/Payment (item 40) 3A 723  */
/*******************************************************************************/
%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

%let SUCCESSYN=Y;
data _null_;
     array _sar_type{12} $20 ('STRUCT' 'TERRORIST' 'FRAUD' 'CASINO' 'ML'
                              'ID' 'OTHER' 'INSURANCE' 'SF' 'MORTGAGE' 
                              'PROD' 'INSTRUMENT');
     array _sar_max{12} 3    ( 7    2    11    5    13    
                               6    19   7     5    5          
                              20    10 );
     do i=1 to dim(_sar_type);
        call symput('_SAR_TYPE_'||strip(put(i,best.)),_sar_type{i});
        call symput('_SAR_MAX_'||strip(put(i,best.)),strip(put(_sar_max{i},best.)));
     end;
run;

%do i=1 %to 12;
    %let _sar_type=&&_sar_type_&i;
     %ecmrr_fincen_concat_cd(indsn=r_x_sar_&_sar_type._type
                            ,outdsn=t_zx_sar_&_sar_type._type
                            ,byvar=rr_rk
                            ,invar=x_sar_&_sar_type._type_cd
                            ,outvar=zx_sar_&_sar_type._type
                            ,maxsize=&&_sar_max_&i);
     %if &successYN=N %then %goto mExit;
%end;


data r_x_sar_type;
    merge      
    %do i=1 %to 12;
    %let _sar_type=&&_sar_type_&i;
          t_zx_sar_&_sar_type._type
                           
    %end;
    ;
    by rr_rk;
run;

%mExit:

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;

%mend;
