/***********************************************************************************/
/* Copyright (c) 2012, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_prvw_fincen_sar_data                                       */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       Transform the RR data for report preview                         */
/* PARAMETERS:                                                                     */
/*                rr_config_rk: key of the report to preview (required)            */
/* NOTE:                                                                           */
/***********************************************************************************/
%macro ecmrr_prvw_fincen_sar_data(rr_rk=, form_config_rk=201);


%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

%ecmrr_fincen_new_sas_format(form_config_rk=&form_config_rk);

%let successYN=Y;
data rr_subset;
     rr_rk=&rr_rk;
run;

%let efile_rk=;

/* transform the data to efile ready format */
%ecmrr_efile_fincen_sar_data(rr_subset_dsn=rr_subset,form_config_rk=&form_config_rk);

/* update the x_filed_dt to the filed date if x_filed_dt is not emtpy */
%let _report_dt=;
proc sql noprint;
     select put(x_filed_dt,best.)  into :_report_dt
     from rr_pivot
     where x_filed_dt > 0 ;
%if &_report_dt ne %then
%do;
     update zx_rr
     set x_filed_dt=&_report_dt
     ;

%end;

/* create filing institution data for sar_s1.pdf */
%let z_institution_cnt=%ecm_nobs(zx_institution);

proc sql;
     create table zx_inst as
     select *,
            'Part III Information about Financial Institution Where Activity Occurred '||strip(put(z_institution_seq_no,best.))||
                  " of &z_institution_cnt"
            as z_header_txt length=100
     from zx_institution
     order by z_institution_seq_no
;


proc sort data=zx_branch force;
     by z_institution_seq_no row_no;
run;
/* prepare institutions where activity occurred data with the first branch data */
/* for sar_s2.pdf                                                               */ 
%let z_institution_cnt=%ecm_nobs(zx_institution);
data zx_inst_branch
     t_zx_branch_more (keep=x_branch_role_cd
                            x_branch_address_txt
                            x_branch_city_nm
                            x_branch_state_cd
                            x_branch_country_cd
                            x_branch_postal_cd
                            x_branch_rssd_id
                            z_institution_seq_no
                            z_header_txt
                        )
;
     merge zx_inst
           zx_branch
     ;
     by z_institution_seq_no;
     if first.z_institution_seq_no then output zx_inst_branch;
     else output t_zx_branch_more;
run;

/* create additional branch data for sar_s3.pdf */
data zx_branch_more;
     set t_zx_branch_more;
     by z_institution_seq_no;

     array z_branch_role_cd {6} $1 x_branch_role_cd_1 - x_branch_role_cd_6;
     array z_branch_address_txt {6} $100 x_branch_address_txt_1 - x_branch_address_txt_6;
     array z_branch_city_nm {6} $50 x_branch_city_nm_1 - x_branch_city_nm_6;
     array z_branch_postal_cd {6} $9 x_branch_postal_cd_1 - x_branch_postal_cd_6;
     array z_branch_state_cd {6} $3 x_branch_state_cd_1 - x_branch_state_cd_6;
     array z_branch_country_cd {6} $2 x_branch_country_cd_1 - x_branch_country_cd_6;
     array z_branch_rssd_id {6} $20 x_branch_rssd_id_1 - x_branch_rssd_id_6;
     retain x_branch_role_cd_1 - x_branch_role_cd_6
            x_branch_address_txt_1 - x_branch_address_txt_6
            x_branch_city_nm_1 - x_branch_city_nm_6
            x_branch_postal_cd_1 - x_branch_postal_cd_6
            x_branch_state_cd_1 - x_branch_state_cd_6
            x_branch_country_cd_1 - x_branch_country_cd_6
            x_branch_rssd_id_1 - x_branch_rssd_id_6
     ;

     if first.z_institution_seq_no then link ARRAY_CLEAR;
     array_i+1;
     if array_i > 6 then
     do;
         output;
         link ARRAY_CLEAR;
         array_i=1;
     end;
     link ARRAY_ASSIGN;
     if last.z_institution_seq_no then output;
     return;

ARRAY_CLEAR:
    do i=1 to 6;
       z_branch_role_cd{i}='';
       z_branch_address_txt{i}='';
       z_branch_city_nm{i}='';
       z_branch_postal_cd{i}='';
       z_branch_state_cd{i}='';
       z_branch_country_cd{i}='';
       z_branch_rssd_id{i}='';
    end;
    array_i=0;
return;

ARRAY_ASSIGN:

       z_branch_role_cd{array_i}=x_branch_role_cd;
       z_branch_address_txt{array_i}=x_branch_address_txt;
       z_branch_city_nm{array_i}=x_branch_city_nm;
       z_branch_postal_cd{array_i}=x_branch_postal_cd;
       z_branch_state_cd{array_i}=x_branch_state_cd;
       z_branch_country_cd{array_i}=x_branch_country_cd;
       z_branch_rssd_id{array_i}=x_branch_rssd_id;


return;

run;

/* concatenate commodity data */
%ecmrr_fincen_concat_txt(indsn=zx_commodity
                            ,outdsn=z_commodity
                            ,byvar=rr_rk
                            ,invar=x_commodity_type_txt
                            ,outvar=zx_commodity_type_txt
                            ,delimiter=%str(, )
                            ,maxsize=32760
                            ,sortedYN=N
                            ,sortby=rr_rk
                            ,fmtnm=
                           );

/* concatenate product data */
%ecmrr_fincen_concat_txt(indsn=zx_product
                            ,outdsn=z_product
                            ,byvar=rr_rk
                            ,invar=x_prod_desc
                            ,outvar=zx_prod_desc
                            ,delimiter=%str(, )
                            ,maxsize=32760
                            ,sortedYN=N
                            ,sortby=rr_rk
                            ,fmtnm=
                           );
/* concatenate CUSIP data */
%ecmrr_fincen_concat_txt(indsn=zx_cusip
                            ,outdsn=z_cusip
                            ,byvar=rr_rk
                            ,invar=x_cusip_no
                            ,outvar=zx_cusip_no
                            ,delimiter=%str(, )
                            ,maxsize=32760
                            ,sortedYN=N
                            ,sortby=rr_rk
                            ,fmtnm=
                           );

/* concatenate market data */
%ecmrr_fincen_concat_txt(indsn=zx_market
                            ,outdsn=z_market
                            ,byvar=rr_rk
                            ,invar=x_mic_cd
                            ,outvar=zx_mic_cd
                            ,delimiter=%str(, )
                            ,maxsize=32760
                            ,sortedYN=N
                            ,sortby=rr_rk
                            ,fmtnm=
                           );

/* concatenate IP address data */
%ecmrr_fincen_concat_txt(indsn=zx_ip_address
                            ,outdsn=z_ip_address
                            ,byvar=rr_rk
                            ,invar=x_ip_address_txt
                            ,outvar=zx_ip_address_txt
                            ,delimiter=%str(, )
                            ,maxsize=32760
                            ,sortedYN=N
                            ,sortby=rr_rk
                            ,fmtnm=
                           );

/* prepare report data for sar_s0, sar_s10. sar_s11, sar_s12 */                           
data z_rr;
     merge zx_rr
           z_commodity (keep=rr_rk zx_commodity_type_txt)
           z_product (keep=rr_rk zx_prod_desc)
           z_cusip (keep=rr_rk zx_cusip_no)
           z_market (keep=rr_rk zx_mic_cd)
           z_ip_address (keep=rr_rk zx_ip_address_txt)
    ;
    by rr_rk;
run;

/* prepare subject data */
%ecmrr_prvw_fincen_sar_subj;

/* prepare SAR narrative for sar_s13 */
data z_sar_narrative_desc_long;
     set z_sar_narrative_desc end=eof;
     length z_sar_narrative_desc_long $ 5100;
     retain z_sar_narrative_desc_long;
     i_desc=mod(_n_,6);
     i_desc_prev=i_desc-1;
     if i_desc_prev < 0 then i_desc_prev=6-1;
     z_sar_narrative_desc_long=substrn(z_sar_narrative_desc_long,1,850*i_desc_prev)||
                               z_sar_narrative_desc;   
     if eof or i_desc=0 then
	 do;
	      /* escape the parenthesis and back slashes */
	      z_sar_narrative_desc_long=
                  tranwrd(
                           tranwrd(
                                   tranwrd(z_sar_narrative_desc_long,'\','\\'
                                           )
                                   ,')','\)'
                                   )
                           ,'(','\('
                          ); 
          output;
     end;
     keep rr_rk z_rr_seq_no z_sar_narrative_desc_long;
run;



%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;
MEXIT:
%mend;
