/*******************************************************************************/
/* Load FINCEN SAR configuration data                                          */
/* To test one the code without loading the data, %let ECM_DBUG=Y;             */
/*******************************************************************************/

 

%macro ecm_loadrr_udf_def_fincen;

/*******************************************************************************/
/*  Load E-FILE UDF fields                                                         */
/*******************************************************************************/

data efile_udf_def_fincen;
if 0 then set ecm_db.efile_udf_def;

     length form_type $ 30;
     infile "&form_path&slash.efile_udf_def_fincen.csv"  
             dsd lrecl=32764 truncover firstobs=2  delimiter=',' ;            
     input form_type $ 
           udf_table_nm $
           udf_nm $
           udf_type_nm $
           max_char_cnt
           udf_desc $
          
           
    ;
    if form_type = 'FINCEN' then output;
    drop form_type;
run;
%if &sysrc <= 4 and &ecm_debug=N %then
%do;
    proc sql noprint;
         delete from ecm_db.efile_udf_def
         where udf_table_nm||udf_nm in 
               (select distinct udf_table_nm||udf_nm from efile_udf_def_fincen)

    ;
    proc append base=ecm_db.efile_udf_def data=efile_udf_def_fincen force;
    run;
%end;

%mend;


%macro ecm_loadrr_ref_naics;

/*******************************************************************************/
/*  LOAD NAICS codes                                                           */
/*******************************************************************************/
 
data ref_table_value_naics;

     if 0 then set ecm_db.Ref_table_value; 
     infile  "&form_path&slash.2007NAICS.csv"  
             dsd lrecl=32764 truncover delimiter=',' ;
     length tmp_str expr $ 128;
     retain ref_table_nm 'X_RT_NAICS';
     retain value_cd value_desc display_order_no; 
     keep  ref_table_nm value_cd value_desc parent_ref_table_nm parent_value_cd display_order_no;
   
     input tmp_str $;
      
     str_len=length(tmp_str);
     expr='/\d{'||strip(put(str_len,best.))||'}/';
      /* check for numeric data for NAICS code */
      if prxmatch(expr,tmp_str)=1  then
      do;
         value_cd=tmp_str;
         display_order_no+1;
         value_desc=strip(value_desc)||' ('||strip(value_cd)||')';
         output;
     end;
     else value_desc=strip(tmp_str);
run;

%if &sysrc <= 4 and &ecm_debug=N %then
%do;
      proc sql noprint;
         delete from ecm_db.ref_table_value
         where ref_table_nm='X_RT_NAICS'
     ;
     quit;
    proc append base=ecm_db.ref_table_value data=ref_table_value_naics force;
    run;
%end;

%mend; 


%macro ecm_loadrr_ref_country_state_cd;

/*******************************************************************************/
/*  LOAD ISO standard country codes                                            */
/*******************************************************************************/
 
data ref_table_value_country;

     if 0 then set ecm_db.Ref_table_value; 
     infile  "&form_path&slash.country_names_and_code_elements.txt"  
             dsd lrecl=32764 truncover firstobs=2 delimiter=';' ;
     
     retain ref_table_nm 'X_RT_COUNTRY';
     retain value_cd value_desc display_order_no; 
     keep  ref_table_nm value_cd value_desc parent_ref_table_nm parent_value_cd display_order_no;
   
     input value_desc $
           value_cd
     ; 
     value_desc=tranwrd(tranwrd(tranwrd(propcase(value_desc),' Of',' of'),' And ',' and '),'The ','the ');

     display_order_no+1;
     if value_cd ne '' then output;
     
run;
/* Set US as the first choice in the list */
proc sql noprint;
     update ref_table_value_country
     set display_order_no=0
     where ref_table_nm='X_RT_COUNTRY' and value_cd='US'
     ;
     /* Exclude US Territories               */
     /* AS - America Samoa                   */
     /* FM - Micronesia, Federated States of */
     /* GU - Guam                            */
     /* MH - Marshall Islands                */
     /* MP - Northern Mariana Islands        */
     /* PR - Puerto Rico                     */
     /* PW - Palau                           */
     /* VI - Virgin Islands, U. S.           */
     delete from ref_table_value_country
     where value_cd in
     ('AS' 'FM' 'GU' 'MH' 'MP' 'PR' 'PW' 'VI')
     ;
quit;

/*******************************************************************************/
/*  LOAD US/CA/MX state codes                                                  */
/*******************************************************************************/
 
data ref_table_value_state;

     if 0 then set ecm_db.Ref_table_value; 
     infile  "&form_path&slash.state_code_list.csv"  
             dsd lrecl=32764 truncover delimiter=',' ;
     
     retain ref_table_nm 'X_RT_STATE_PROVINCE'
            parent_ref_table_nm 'X_RT_COUNTRY'
     ;
     retain value_cd value_desc display_order_no; 
     keep  ref_table_nm value_cd value_desc parent_ref_table_nm parent_value_cd display_order_no;
   
     input parent_value_cd $
           value_cd $ 
           value_desc $
     ;
     if lag(parent_value_cd) ne parent_value_cd then display_order_no=1;
     else display_order_no+1;
         
run;

%if &sysrc <= 4 and &ecm_debug=N %then
%do;
    proc sql noprint;
         delete from ecm_db.ref_table_value
         where ref_table_nm='X_RT_STATE_PROVINCE'
    ;
         delete from ecm_db.ref_table_value
         where ref_table_nm='X_RT_COUNTRY'
    ;
    quit;

    proc append base=ecm_db.ref_table_value data=ref_table_value_country force;
    run;
    
    proc append base=ecm_db.ref_table_value data=ref_table_value_state force;
    run;
%end;

%mend; 



  
  
/* Change ecm_debug to Y for testing */
%let ecm_debug=N;
/* Adjust the sequence number if it has been used */
%let form_path=&ecm_config_path&slash.Source&slash.form_template;


%ecm_loadrr_udf_def_fincen;   /* load E-file UDF fields            */
%ecm_loadrr_ref_naics;        /* load NASICS code                  */

%ecm_loadrr_ref_country_state_cd;   /* ISO standard country codes        */



 
