
/***********************************************************************************/
/* Copyright (c) 2011-2012, SAS Institute Inc., Cary, NC, USA, All Rights Reserved */
/*                                                                                 */
/* NAME:          ecm_mkdir                                                        */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       create directory if it does not exist.                           */
/*                return the final status of the directory                         */
/* PARAMETERS:                                                                     */
/*                pathname: path of the directory                                  */
/*                rcVAR: mac variable for return code                              */
/*                       1 when the path is created                                */
/*                       0 when it is not created                                  */
/*                resetYN: Y to delete all existing files                          */
/* NOTE:                                                                           */
/***********************************************************************************/


%macro ecm_mkdir(pathname=,rcvar=RC,resetYN=N);

%local CreateStmt RemoveStmt;
%let &rcvar=0;

data _null_;
     if symget('sysscp') eq "WIN" then
     do; /* double quotes are needed to quote the physical paths on Windows because the paths may contain spaces */ 
        call symput('CreateStmt',"'"||symgetc('mkdirCmd')||' "'||strip(symgetc('pathname'))||'"'||"'");
        call symput('RemoveStmt',"'"||symgetc('delCmd')||'/Q "'||strip(symgetc('pathname'))||"&slash"||'*.*'||'"'||"'");
     end;
     else
     do;
        call symput('CreateStmt',"'"||symgetc('mkdirCmd')||' '||strip(symgetc('pathname'))||"'");
        call symput('RemoveStmt',"'"||symgetc('delCmd')||' '||strip(symgetc('pathname'))||"&slash"||'*.*'||"'");
     end;
     
run; 
 


%if %sysfunc(fileexist(&pathname)) =0  %then
%do;

/* using pipe instead of x command to create directory */

   filename mkdir pipe &CreateStmt;
   data _null_;
        infile mkdir;
        input;
        stop;
   run;
   
%end;
%else 
%do;
    %if %upcase(&resetYN)=Y %then
    %do;
       
      filename rmdir pipe &RemoveStmt;
      data _null_;
             infile rmdir;
      input;
      stop;
     run;
     filename rmdir clear;
    %end;
  
%end;

%let &rcvar=%sysfunc(fileexist(&pathname));

%mExit: 

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;

%mend;
 
