
/***********************************************************************************/
/* Copyright (c) 2012, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_efile_fincen_newctr_driver                                 */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       Driver program for generating new FINCEN CTR e-files             */
/* PARAMETERS:                                                                     */
/*                form_config_rk: form configuration key                           */
/* NOTE:                                                                           */
/***********************************************************************************/

%macro ecmrr_efile_fincen_newctr_driver(form_config_rk=202);

%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

%let successYN=Y;
 

/* set missing option to blank to avoid '.' being used as missing values */
options missing=' '; 
%let efile_file_prefix=;
%let efile_form_type_cd=;

/* retrieve efile config info */ 
proc sql noprint;

         select trim(efile_file_prefix),
                upcase(trim(form_type_cd))
           into :efile_file_prefix,
                :efile_form_type_cd
         from ecm_db.form_config
         where form_config_rk=&form_config_rk;

         create table form_efile_record_config as
         select *
         from ecm_db.form_efile_record_config
         where form_config_rk=&form_config_rk
         order by record_sort_order_no;
         ;
         %let form_efile_record_cnt=&sqlobs;
quit;
 

%if &syserr > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;

/* retrieve record level configration data */
proc sql noprint;
     select form_efile_record_seq_no,
            source_table_nm,
            form_efile_record_id
      into :form_efile_record_seq_no1 - :form_efile_record_seq_no&form_efile_record_cnt,
           :source_table_nm1 - :source_table_nm&form_efile_record_cnt,
           :form_efile_record_id1 - :form_efile_record_id&form_efile_record_cnt
     from form_efile_record_config
     ;
   
    
     /* all record lengths are supposed to be the same */ 
     select max(record_length_no) into :record_length_no
     from form_efile_record_config
     ;
/* get all the source field for each record type */
/* Note: source_field_exp should not refer to the a data field that is not part of the source field of the table */

%do record_i=1 %to &form_efile_record_cnt;
      select distinct source_field_nm
             into :source_field_nm&record_i separated by ' '        
       from ecm_db.form_efile_field_config as a, 
            dictionary.columns as b
     where a.form_config_rk=&form_config_rk 
           and a.form_efile_record_seq_no=&&&form_efile_record_seq_no&record_i
           and b.libname='WORK' 
           and upcase(b.memname)=upcase("&&&source_table_nm&record_i") 
           and upcase(a.source_field_nm)=upcase(b.name)
     ;
  
%end;

%if &syserr > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;
 
/* load the macros specific to the form identified by form_config_rk */
%if "%trim(&efile_file_prefix)" = "" %then %let efile_file_prefix=efile_&form_config_rk;
filename efilemac "&ecm_config_ucmacro_path&slash.%trim(&efile_file_prefix)_efile_macro.sas";

%inc efilemac;
 
/* Define efile_output_info table for */

%if %str(&efile_rk) ne %str() %then 
%do; 


/* If efile_rk is provided, pull the efile data from efile_live */

       data efile_output_info;
            merge ecm_db.efile_live (where=(efile_rk=&efile_rk))
                  &source_table_nm1  (where=(z_batch_seq_no=1) /* only process the first batch if an efile_live record is defined */
                                     keep=z_batch_seq_no z_coverage_start_dt z_coverage_end_dt ) 
                   &&&source_table_nm&form_efile_record_cnt
                                    (where=(z_batch_seq_no=1) /* only process the first batch if an efile_live record is defined */
                                     keep=z_batch_seq_no z_rr_cnt 
                                     )  
                            
         ;
         length x_output_zip_nm $ 64;
         output_nm=strip(efile_id)||'.dat';
         output_create_dttm=datetime();         
         output_path_nm="&efile_file_prefix";       
         output_rr_cnt=z_rr_cnt;         
         coverage_start_dt=z_coverage_start_dt*3600*24;
         coverage_end_dt=z_coverage_end_dt*3600*24; 
         x_output_zip_nm='';
         call symput ('BATCH_CNT','1');
         call symput('output_path_nm',strip(output_path_nm));
         call symput('output_nm_1',strip(output_nm));
         drop z_coverage_start_dt z_coverage_end_dt z_rr_cnt
              ;
        

      run;  
      
      %if &syserr > 4 %then 
      %do;
          %let successYN=N;
          %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
          %goto mExit;
      %end;
%end;


%do batch_i=1 %to &batch_cnt;     

    %let efile_subpath=%trim(&ecm_efile_path)&slash.%trim(&output_path_nm);
    
  
    filename efilenm "&efile_subpath&slash.&&output_nm_&batch_i.";
 

    data _null_;
         file efilenm lrecl=&record_length_no pad termstr=CRLF;
         length target_field_value $ &record_length_no; 
         set 
        
     %do record_i=1 %to &form_efile_record_cnt;
               &&&source_table_nm&record_i 
               (keep= z_batch_seq_no z_filing_inst_seq_no z_inst_seq_no z_rr_seq_no 
                      z_subject_seq_no form_efile_record_id
                    &&&source_field_nm&record_i
                )
     %end;
          ;      
          by z_filing_inst_seq_no z_inst_seq_no z_rr_seq_no z_subject_seq_no;
          where z_batch_seq_no=&batch_i;

     %do record_i=1 %to &form_efile_record_cnt;
           if form_efile_record_id="&&&form_efile_record_id&record_i" then 
               link WRT_&&&form_efile_record_id&record_i;
     %end;
         return;
     %do record_i=1 %to &form_efile_record_cnt;
           WRT_&&&form_efile_record_id&record_i:
           %form_&form_config_rk._&&&form_efile_record_id&record_i;
           put; 
           return;
     %end;           
                stop; 
    run;    
 
    %if &syserr > 4 %then 
    %do;
        %let successYN=N;
        %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
        %goto mExit;
    %end;
                             
             
        
       /* obtain file size and creation datetime */
       %let output_create_dttm=%sysfunc(datetime());
       data _null_;
            fid=fopen('efilenm');
            call symput('output_file_size',strip(finfo(fid,'File Size (bytes)')));
            rc=fclose (fid);
       run; 

       %if &syserr > 4 %then 
       %do;
           %let successYN=N;
           %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
           %goto mExit;
        %end;
       filename efilenm clear;
       /* update efile_output_info with the file size and actual creation datetime */
       proc sql;
            update efile_output_info
            set output_file_size=&output_file_size,
                output_create_dttm=&output_create_dttm,
                output_line_cnt=round(&output_file_size/(&record_length_no+2),1)
            where z_batch_seq_no=&batch_i
       ;
       quit;

      %if &syserr > 4 %then 
      %do;
          %let successYN=N;
          %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
          %goto mExit;
       %end;     
  


%end; /* end loop by batch_i */


%if %upcase(&ecm_run_soap=Y) %then
%do;


    %let filed_dt_exist=N;
    proc sql noprint;
        select 'Y' into :filed_dt_exist
        from ecm_db.rr_udf_def
        where udf_table_nm='RR' and udf_nm='X_FILED_DT';
    quit;

     
    %if &filed_dt_exist=Y %then
    %do;
        data _null_;
        call symput('x_filed_dt',put(today(),best.));
        run;

        %ecmrr_efile_update_rr (form_config_rk=,
                                rr_indsn=zx_rr,
                                efile_dt_var=x_filed_dt,
                                efile_dt_value=&x_filed_dt);
    %end;
    %else
    %do;

        %ecmrr_efile_update_rr (form_config_rk=,
                                 rr_indsn=zx_rr,
                                 efile_dt_var=,
                                 efile_dt_value=);
    %end;



%end;


%mexit:

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;

%mend;
