/***********************************************************************************/
/* Copyright (c) 2012, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_efile_fincen_newctr_seqno                                  */
/* PRODUCT:       Enterprise rr Management                                         */
/* PURPOSE:       Assign sequence number to the records that will be efiled,       */
/*                per FINCEN new form requirement.                                 */
/* PARAMETERS:                                                                     */
/*                in_dsn: name of the input table                                  */
/*                out_dsn: name of the output table                                */
/*                seq_dsn: name of the table containing all the sequence  numbers  */
/*                z_subject_seq_no: value to use for z_subject_seq_no, leave it as */
/*                                  blank if the input data has z_subject_seq_no   */
/*                row_no:           value to use for row_no, leave it as blank     */
/*                                  blank if the input data has row_no             */
/*                form_efile_record_id: value for form_efile_record_id, leave it   */
/*                                      blank if form_efile_record_id is in the    */
/*                                      input table                                */
/***********************************************************************************/
%macro ecmrr_efile_fincen_newctr_seqno(in_dsn=
                                       ,out_dsn=
                                       ,seq_dsn=
                                       ,z_subject_seq_no=
                                       ,row_no=
                                       ,form_efile_record_id=
                                      ); 
                                    

%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

proc sql noprint;
     create table &out_dsn as
     select a.*
            , b.z_batch_seq_no
            , b.z_filing_inst_seq_no
            , b.z_inst_seq_no
            , b.z_rr_seq_no

%if %str(&z_subject_seq_no) ne %str()  %then
%do;
            , &z_subject_seq_no as z_subject_seq_no
%end;
%if %str(&row_no) ne %str()  %then
%do;
            , &row_no as row_no
%end;
%if %str(&form_efile_record_id) ne %str()  %then
%do;
            , "&form_efile_record_id" as form_efile_record_id
%end;
     from &in_dsn as a,
          &seq_dsn as b
     where a.rr_rk=b.rr_rk
     order by  z_batch_seq_no
               , z_filing_inst_seq_no
               , z_inst_seq_no
               , z_rr_seq_no
               , z_subject_seq_no
               , row_no
     ;
 quit;


       

 
%if &syserr > 4 %then
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;

%mExit:

%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

%mend;

 
