/***********************************************************************************/
/* Copyright (c) 2012, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_efile_fincen_sar_seqno                                     */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       Assign sequence number to the records that will be efiled,       */
/*                per FINCEN new form requirement.                                 */
/* PARAMETERS:                                                                     */
/*                source_table_nm: name of the input table                         */
/*                seq_no_table_nm: name of the table containing all the sequence   */
/*                                 numbers                                         */
/*                byvar: name of key variables                                     */
/*                target_table_nm: name of the output table                        */
/* NOTE:                                                                           */
/* z_batch_seq_no, z_filing_inst_seq_no, z_rr_seq_no                               */
/* must exist in <seq_table_nm>                                                    */
/* if z_institution_seq_no exist in <seq_table_nm>, z_institution_seq_no and       */
/* institution_rk_var_nm should be blank                                           */
/* otherwise either z_institution_seq_no or institution_rk_var_nm should not be blank*/
/* if z_subject_seq_no exist in <seq_table_nm>, z_subject_seq_no and               */
/* subject_rk_var_nm should be blank                                               */
/* otherwise either z_subject_seq_no or subject_rk_var_nm should not be blank      */
/***********************************************************************************/
%macro ecmrr_efile_fincen_sar_seqno(source_table_nm=,
                                    seqno_table_nm=, 
                                    byvar=,
                                    target_table_nm=,
                                    form_config_rk=201,
                                    z_institution_seq_no=99999,
                                    institution_rk_var_nm=,
                                    z_subject_seq_no=0,
                                    subject_rk_var_nm=);

%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

proc sql noprint;
     select put(form_efile_record_seq_no,best.),
            form_efile_record_id,
            record_sort_order_no,
            page_by_field_nm
     into    
            :form_efile_record_seq_no,
            :form_efile_record_id,
            :record_sort_order_no,
            :page_by_field_nm 
     from ecm_db.form_efile_record_config
     where upcase(source_table_nm)="%upcase(&target_table_nm)" and form_config_rk=&form_config_rk
     ;
     %let row_no_exist=0;
     select '1' into :row_no_exist 
     from dictionary.columns
     where libname='WORK' and upcase(memname)="%upcase(&source_table_nm)" and
           name='ROW_NO'
     ;
     create table &target_table_nm as
     select a.*
            , b.z_batch_seq_no
            , b.z_filing_inst_seq_no
            , b.z_rr_seq_no
%if &institution_rk_var_nm ne  %then
%do;
              ,b.z_institution_seq_no
%end;
%else %if &z_institution_seq_no ne %then 
%do;
             , &z_institution_seq_no as z_institution_seq_no
%end;

           
%if &subject_rk_var_nm ne  %then
%do;
              ,b.z_subject_seq_no
%end;
%else %if &z_subject_seq_no ne %then 
%do;
             , &z_subject_seq_no as z_subject_seq_no
%end;

             , "&form_efile_record_id" as form_efile_record_id
             ,&record_sort_order_no as record_sort_order_no     
     from &source_table_nm as a,
          &seqno_table_nm as b        
     where a.&byvar=b.&byvar 
%if &subject_rk_var_nm ne %then
%do;
           and a.&subject_rk_var_nm=b.&subject_rk_var_nm
%end;
%if &institution_rk_var_nm ne %then
%do;
           and a.&institution_rk_var_nm=b.&institution_rk_var_nm
%end;
     order by   z_batch_seq_no
              , z_filing_inst_seq_no
              , z_rr_seq_no
              , z_institution_seq_no 
              , z_subject_seq_no
%if &row_no_exist %then 
%do;
              , row_no
%end;
     ;
     create index z_rr_seq_no on &target_table_nm;
quit;

%if &syserr > 4 %then
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;

%mExit:

%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

%mend;

 
