
/***********************************************************************************/
/* Copyright (c) 2011, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_efile_fincen_sar_sum                                       */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       summarize the detail data prepared by                            */
/*                ecmrr_efile_fincen_sar_detail and assign sequence number for     */
/*                batch e-filing                                                   */                                                
/* PARAMETERS:                                                                     */
/*                form_config_rk: form config key                                  */
/* NOTE:          Input tables:                                                    */
/*                  x_transmitter             (1A)                                 */  
/*                  t_zx_institution          (2B)                                 */ 
/*                  r_x_branch                (2C)                                 */ 
/*                  t_zx_rr                   (3A, 2A, 9B, 9Z)                     */ 
/*                  r_x_commodity             (3B)                                 */
/*                  r_x_product               (3C)                                 */
/*                  r_x_market                (3D)                                 */
/*                  r_x_ip_address            (3E)                                 */
/*                  r_x_cusip                 (3F)                                 */                                              
/*                  t_zx_subject              (4A)                                 */
/*                  r_x_subject_address       (4B)                                 */
/*                  r_x_subject_id            (4C)                                 */
/*                  r_x_subject_alternate_nm  (4D)                                 */
/*                  r_x_subject_telephone_no  (4E)                                 */
/*                  r_x_subject_email_address (4F)                                 */
/*                  r_x_subject_url_address   (4G)                                 */
/*                  t_zx_subject_relation_inst(4H)                                 */
/*                  t_zx_subject_inst_acct    (4I)                                 */
/*                  t_z_sar_narrative_desc    (5A)                                 */
/*                  t_z_sum_rr                (9A)                                 */
/*                Output tables:                                                   */
/*                  zx_transmitter            (1A)                                 */  
/*                  zx_filing_inst            (2A)                                 */
/*                  zx_institution            (2B)                                 */  
/*                  zx_branch                 (2C)                                 */ 
/*                  zx_rr                     (3A)                                 */ 
/*                  zx_commodity              (3B)                                 */
/*                  zx_product                (3C)                                 */
/*                  zx_market                 (3D)                                 */
/*                  zx_ip_address             (3E)                                 */
/*                  zx_cusip                  (3F)                                 */
/*                  zx_subject                (4A)                                 */
/*                  zx_subject_address        (4B)                                 */
/*                  zx_subject_id             (4C)                                 */
/*                  zx_subject_alternate_nm   (4D)                                 */
/*                  zx_subject_telephone_no   (4E)                                 */
/*                  zx_subject_email_address  (4F)                                 */
/*                  zx_subject_url_address    (4G)                                 */
/*                  zx_subject_relation_inst  (4H)                                 */
/*                  zx_subject_inst_acct      (4I)                                 */
/*                  zx_sar_narrative_desc     (5A)                                 */
/*                  z_sum_rr                  (9A)                                 */
/*                  z_sum_filing_inst         (9B)                                 */
/*                  z_sum_transmitter         (9Z)                                 */
/***********************************************************************************/

%macro ecmrr_efile_fincen_sar_sum(form_config_rk=201);

%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

%let successYN=Y;
/* get the max number of reports can be added to the efile for this form type */
%let efile_max_rr_cnt=0;

proc sql noprint;
     select efile_max_rr_cnt into : efile_max_rr_cnt
     from ecm_db.form_config
     where form_config_rk=&form_config_rk;

%if &efile_max_rr_cnt < 1 %then %let efile_max_rr_cnt=700; 

/*****************************************************************************/
/* create sequence numbers by batch, filing institution, and rr              */
/*****************************************************************************/
                    
/* sort reports by filing institution and report rk */
   proc sort data=t_zx_rr (keep=x_institution_rk rr_rk) 
             out=key_sorted;
        by x_institution_rk rr_rk;
        
   run;

%if &syserr > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;

/* create z_batch_seq_no, z_filing_inst_seq_no, and z_rr_seq_no */
   data t_z_seq_no  ;
        set key_sorted;
        by x_institution_rk rr_rk; 

        retain z_batch_seq_no 0;
        retain z_filing_inst_seq_no 0;

        /* rr_seq_no is unique within a batch, not within a filing institution */
        
        if mod(_n_,&efile_max_rr_cnt)=1 then
        do;
           z_batch_seq_no+1;
           if first.x_institution_rk then z_filing_inst_seq_no=0;
           else z_filing_inst_seq_no=1;
           z_rr_seq_no=0;
        end;
        if first.x_institution_rk then
        do;
                z_filing_inst_seq_no+1;
        end;
         
        z_rr_seq_no+1;
       
    run;

%if &syserr > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;
         
/****************************************************/
/* assign RR seq number to RR level tables          */
/****************************************************/ 
%ecmrr_efile_fincen_sar_seqno(source_table_nm=t_zx_rr,
                                     seqno_table_nm=t_z_seq_no,byvar=rr_rk, 
                                     target_table_nm=zx_rr,form_config_rk=&form_config_rk);
%if &successYN=N %then %goto mExit;

%ecmrr_efile_fincen_sar_seqno(source_table_nm=t_z_sum_rr,
                                     seqno_table_nm=t_z_seq_no,byvar=rr_rk, 
                                     target_table_nm=z_sum_rr,form_config_rk=&form_config_rk);
/* force the subject sequence number to be the highest so that that the record will appear after all the 4A records */
proc sql noprint;
     update z_sum_rr
     set z_subject_seq_no=99999
     ;
quit;
%if &successYN=N %then %goto mExit;

%ecmrr_efile_fincen_sar_seqno(source_table_nm=t_z_sar_narrative_desc,
                              seqno_table_nm=t_z_seq_no,
                              byvar=rr_rk,
                              target_table_nm=z_sar_narrative_desc,
                              form_config_rk=&form_config_rk);

/* force the subject sequence number to be the highest so that that the record will appear after all the 4A records */

proc sql noprint;
     update z_sar_narrative_desc
     set z_subject_seq_no=99999
     ;
quit;
%if &successYN=N %then %goto mExit;

%ecmrr_efile_fincen_sar_seqno(source_table_nm=r_x_commodity,
                              seqno_table_nm=t_z_seq_no,
                              byvar=rr_rk,
                              target_table_nm=zx_commodity,
                              form_config_rk=&form_config_rk);
%if &successYN=N %then %goto mExit;

%ecmrr_efile_fincen_sar_seqno(source_table_nm=r_x_product,
                              seqno_table_nm=t_z_seq_no,
                              byvar=rr_rk,
                              target_table_nm=zx_product,
                              form_config_rk=&form_config_rk);
%if &successYN=N %then %goto mExit;

%ecmrr_efile_fincen_sar_seqno(source_table_nm=r_x_market,
                              seqno_table_nm=t_z_seq_no,
                              byvar=rr_rk,
                              target_table_nm=zx_market,
                              form_config_rk=&form_config_rk);
%if &successYN=N %then %goto mExit;

%ecmrr_efile_fincen_sar_seqno(source_table_nm=r_x_ip_address,
                              seqno_table_nm=t_z_seq_no,
                              byvar=rr_rk,
                              target_table_nm=zx_ip_address,
                              form_config_rk=&form_config_rk);
%if &successYN=N %then %goto mExit;

%ecmrr_efile_fincen_sar_seqno(source_table_nm=r_x_cusip,
                              seqno_table_nm=t_z_seq_no,
                              byvar=rr_rk,
                              target_table_nm=zx_cusip,
                              form_config_rk=&form_config_rk);
%if &successYN=N %then %goto mExit;

/* set z_institution_seq_no paraemter to blank to use the z_institution_seq_no from the input data */
%ecmrr_efile_fincen_sar_seqno(source_table_nm=t_zx_institution,
                              seqno_table_nm=t_z_seq_no,
                              byvar=rr_rk,
                              target_table_nm=zx_institution,
                              z_institution_seq_no=,
                              form_config_rk=&form_config_rk);
%if &successYN=N %then %goto mExit;

%ecmrr_efile_fincen_sar_seqno(source_table_nm=r_x_branch,
                              seqno_table_nm=zx_institution,
                              byvar=rr_rk,
                              target_table_nm=zx_branch,
                              institution_rk_var_nm=x_inst_rk,
                              form_config_rk=&form_config_rk);
%if &successYN=N %then %goto mExit;


/* set z_subject_seq_no paraemter to blank to use the z_subject_seq_no from the input data */
%ecmrr_efile_fincen_sar_seqno(source_table_nm=t_zx_subject,
                              seqno_table_nm=t_z_seq_no,
                              byvar=rr_rk, 
                              target_table_nm=zx_subject,
                              form_config_rk=&form_config_rk,
                              z_subject_seq_no=);
%if &successYN=N %then %goto mExit;



/*********************************************************************************/
/* Assign rr sequence number and subject sequence number to subject level data   */
/*********************************************************************************/

%ecmrr_efile_fincen_sar_seqno(source_table_nm=r_x_subject_address,
                              seqno_table_nm=zx_subject, 
                              byvar=rr_rk,
                              subject_rk_var_nm=x_subject_rk,
                              form_config_rk=&form_config_rk,
                              target_table_nm=zx_subject_address);

%ecmrr_efile_fincen_sar_seqno(source_table_nm=r_x_subject_id,
                              seqno_table_nm=zx_subject, 
                              byvar=rr_rk,
                              subject_rk_var_nm=x_subject_rk,
                              form_config_rk=&form_config_rk,
                              target_table_nm=zx_subject_id);
                               
%ecmrr_efile_fincen_sar_seqno(source_table_nm=r_x_subject_alternate_nm,
                              seqno_table_nm=zx_subject, 
                              byvar=rr_rk,
                              subject_rk_var_nm=x_subject_rk,
                              form_config_rk=&form_config_rk,
                              target_table_nm=zx_subject_alternate_nm);

%ecmrr_efile_fincen_sar_seqno(source_table_nm=r_x_subject_telephone_no,
                              seqno_table_nm=zx_subject, 
                              byvar=rr_rk,
                              subject_rk_var_nm=x_subject_rk,
                              form_config_rk=&form_config_rk,
                              target_table_nm=zx_subject_telephone_no);
%ecmrr_efile_fincen_sar_seqno(source_table_nm=r_x_subject_email_address,
                              seqno_table_nm=zx_subject, 
                              byvar=rr_rk,
                              subject_rk_var_nm=x_subject_rk,
                              form_config_rk=&form_config_rk,
                              target_table_nm=zx_subject_email_address);

%ecmrr_efile_fincen_sar_seqno(source_table_nm=r_x_subject_url_address,
                              seqno_table_nm=zx_subject, 
                              byvar=rr_rk,
                              subject_rk_var_nm=x_subject_rk,
                              form_config_rk=&form_config_rk,
                              target_table_nm=zx_subject_url_address);

%ecmrr_efile_fincen_sar_seqno(source_table_nm=t_zx_subject_relation_inst,
                              seqno_table_nm=zx_subject, 
                              byvar=rr_rk,
                              subject_rk_var_nm=x_subject_rk,
                              form_config_rk=&form_config_rk,
                              target_table_nm=zx_subject_relation_inst);

%ecmrr_efile_fincen_sar_seqno(source_table_nm=t_zx_subject_inst_acct,
                              seqno_table_nm=zx_subject, 
                              byvar=rr_rk,
                              subject_rk_var_nm=x_subject_rk,
                              form_config_rk=&form_config_rk,
                              target_table_nm=zx_subject_inst_acct);




/********************************************/
/* Create z_filing_inst (2A)                */
/********************************************/ 
/* remove duplicated filing institution information */ 
proc sort data=zx_rr (keep= z_batch_seq_no
                            z_filing_inst_seq_no
                            z_rr_seq_no
                            z_institution_seq_no
                            z_subject_seq_no
                            form_efile_record_id
                            X_FILING_INST_PRIM_FED_REG_CD
                            X_FILING_INST_NM
                            X_FILING_INST_TIN_NO
                            X_FILING_INST_TIN_TYPE_CD
                            X_FILING_INST_TYPE_CD
                            X_FILING_INST_TYPE_OTH_TXT 
                            ZX_FILING_INST_SF_TYPE
                            X_FILING_INST_SF_TYPE_OTH_TXT 
                            X_FILING_INST_ID_TYPE_CD
                            X_FILING_INST_ID_NO
                            X_FILING_INST_ADDRESS_TXT 
                            X_FILING_INST_CITY_NM 
                            X_FILING_INST_STATE_CD 
                            X_FILING_INST_POSTAL_CD 
                            X_FILING_INST_COUNTRY_CD 
                            X_FILING_INST_ALTERNATE_NM)
          out=zx_filing_inst 
          nodupkey;
     by z_batch_seq_no z_filing_inst_seq_no;
run;
/* set record id to 2A */
proc sql noprint;
     /* force rr and subject sequence to be the highest so that 9B record will be after all the 3A records */
     update zx_filing_inst 
     set form_efile_record_id='2A',
         z_institution_seq_no=0,
         z_rr_seq_no=0
    ; 
       
quit;

 
%if &syserr > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;



/********************************************/
/* Create z_sum_filing_inst (9B)            */
/********************************************/ 
proc summary data=z_sum_rr nway missing;
          class z_batch_seq_no z_filing_inst_seq_no; 
          id z_rr_seq_no z_institution_seq_no z_subject_seq_no form_efile_record_id;
          var z_institution_cnt z_branch_cnt z_subject_cnt z_sar_narrative_cnt z_attachment_cnt;
          output out=z_sum_filing_inst sum= n=z_rr_cnt;
run;
proc sql noprint;
     /* force rr and subject sequence to be the highest so that 9B record will be after all the 3A records */
     update z_sum_filing_inst 
     set z_rr_seq_no=99999,
         z_institution_seq_no=99999,
         z_subject_seq_no=99999,
         form_efile_record_id='9B'
    ; 
       
quit;

%if &syserr > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;
   
 

/********************************************/
/* Create zx_transmitter (1A)               */
/********************************************/ 


 proc sql noprint;
    %let record_id_len=0;
    select put(length,best.) into :record_id_len 
    from dictionary.columns
    where libname='WORK' and upcase(memname)='FORM_EFILE_RECORD_CONFIG'
          and upcase(name)='FORM_EFILE_RECORD_ID'
   ; 

   create table zx_transmitter as
     select  a.*,
             b.z_batch_seq_no,
             0 as z_filing_inst_seq_no,
             0 as z_institution_seq_no,
             0 as z_branch_seq_no,
             0 as z_rr_seq_no,
             0 as z_subject_seq_no,
             b.z_coverage_start_dt,
             case
                when b.z_coverage_end_dt > . then b.z_coverage_end_dt                
                else today()
             end as z_coverage_end_dt format=yymmddn8.,
             '1A' as form_efile_record_id length=&record_id_len
     from x_transmitter as a,
          (select min(x_sar_begin_dt) as z_coverage_start_dt format=yymmddn8.,
           max(x_sar_end_dt) as z_coverage_end_dt format=yymmddn8.,
           z_batch_seq_no
           from zx_rr
           group by z_batch_seq_no) as b         
     ;

quit; 

%if &syserr > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end; 
     
/********************************************/
/* Create z_sum_transmitter  (9Z)           */
/********************************************/ 
 

proc summary data=z_sum_filing_inst missing nway;
          class z_batch_seq_no ;
          id z_filing_inst_seq_no z_rr_seq_no z_institution_seq_no z_subject_seq_no form_efile_record_id; 
          var z_institution_cnt z_branch_cnt z_rr_cnt z_subject_cnt z_sar_narrative_cnt z_attachment_cnt;
          output out=z_sum_transmitter sum= n=z_filing_inst_cnt;
run;


proc sql noprint;

    update z_sum_transmitter
    set z_filing_inst_seq_no=99999,
        z_rr_seq_no=99999,
        z_institution_seq_no=99999,
        z_subject_seq_no=99999,
        form_efile_record_id='9Z'
        ;

quit;

%if &syserr > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;


%MEXIT: 

    %if &ecm_debug=N %then
    %do;
        proc datasets nolist nowarn lib=work;
             delete t_zx:
                    t_z_:
                    r_x:
             ;
        quit;
    %end;


%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;


%mend;
 
