/***********************************************************************************/
/* Copyright (c) 2011, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_fdf_merger                                                 */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       Merge fdfs into a final pdf                                      */
/* PARAMETERS:    form_preview_config_table: form preview section config table     */
/*                which is created from ecm_db.form_config and                     */
/*                ecm_db.form_preview_section_config based on form_config_rk       */
/*                                                                                 */
/* NOTE:          input table should be created by ecmrr_fdf_driver                */
/*                fdf files are data file that can be imported/exported into/from  */
/*                a pdf form.                                                      */
/***********************************************************************************/

%macro ecmrr_fdf_merger(form_preview_config_table_nm=form_preview_section_config
                        );
 
                      
%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;
data _null_ / picklist='entcm/entcmjars.txt';

   /* Instantiate the FDFMerger java object */
   declare javaobj f;
   f = _new_ javaobj('com/sas/solutions/casemgmt/util/pdf/FDFMerger');

   /* Set the directories for the master pdf form, temporary fdf files, and the output pdf */
   formpath="&ecm_config_path&slash.Source&slash.form_template";
   temppath=pathname('work');
   outpath=pathname('work');
   f.callVoidmethod('setPaths',strip(formpath),strip(temppath),strip(outpath));
   
   length source_table_nm  
          preview_file_prefix 
          section_file_suffix  
          $ 1024;
   /* loop thru the section configuration table to read the fdf files generated       */
   /* the calling program. Each master pdf defined in the section configration table  */
   /* may have multiple fdf files.                                                    */
	
   section_dsid=open('form_preview_section_config');
   
   do while (fetch(section_dsid) =0);
       /* find out the name of the source table and file prefixes */
       source_table_nm=getvarc(section_dsid,varnum(section_dsid,'SOURCE_TABLE_NM'));
	   preview_file_prefix=getvarc(section_dsid,varnum(section_dsid,'PREVIEW_FILE_PREFIX'));
	   section_file_suffix=getvarc(section_dsid,varnum(section_dsid,'SECTION_FILE_SUFFIX'));
        
       if source_table_nm > '' then
	   do;
	       src_dsid=open(source_table_nm);	    
		  
		   if src_dsid > 0 then 
		   do;
		       /* for each source table, get the name of the fdf file based on the number of records in the table */
	           /* then add the fdf as a page to the output pdf                                                    */
		       do ipage=1 to   attrn(src_dsid,'NOBS')  ;
			       template_nm=strip(preview_file_prefix)
	                                 ||strip(section_file_suffix)
									 ||'.pdf';
				   fdf_nm=strip(preview_file_prefix)
	                                 ||strip(section_file_suffix)
									 ||'_p'||strip(put(ipage,best.))
									 ||'.fdf';				  
				   
				   if fileexist(strip(temppath)||"&slash"||strip(fdf_nm)) then
			           f.callVoidmethod('addPage'
	                                    ,strip(template_nm)
								     	,strip(fdf_nm)
	                                    );
	 
	           end;
			   src_dsid=close(src_dsid);
		   end;
		end;
   end; 
   section_dsid=close(section_dsid); 

    
   /* Build the final pdf output */
   f.callVoidmethod('buildMasterPDFDocument',strip(preview_file_prefix)||'.pdf');   
   
   f.flushjavaoutput();
   f.delete();
 
   
run;

 

   
%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;
MEXIT: 
%mend;
