

/***********************************************************************************/
/* Copyright (c) 2012, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_fdf_new_driver                                             */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       driver program to generate fdf files  page by page               */
/*                                                                                 */
/* PARAMETERS:                                                                     */
/*                form_preview_config_table_nm: name of the preview config         */
/*                       table that has the paging information                     */
/*                       by_var is required                                        */
/*                       The first source table in the config table will be used   */
/*                       to determine the list of by values.                       */
/*                last_page_no_mvar: name of the macro variable for tracking the   */
/*                                   last used page number.                        */
/*                total_page_no: total number of pages in the entire output        */
/* NOTE:          the fdf output is saved in the work directory                    */
/*                For testing:                                                     */
/*                To see the fdf in pdf form, copy the .pdf form to the work       */
/*                directory. Then click on the fdf file. Adobe reader is required. */
/***********************************************************************************/
%macro ecmrr_fdf_new_subdriver(form_preview_config_table_nm=
                               ,last_page_no_mvar=last_page_no
                               ,total_page_no= 
                               );
%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;


%let by_value_cnt=0;
 
     data _null_;
        /* use the first source table to obtain the full list of by_var values */
        set &form_preview_config_table_nm (obs=1 keep=source_table_nm by_var);
        i_by_value=0;
        if by_var ne '' then
        do;
           by_master_dsid=open(source_table_nm);     
           do while (fetch(by_master_dsid) =0);
              i_by_value+1;
              by_value=getvarn(by_master_dsid,varnum(by_master_dsid,by_var));
              put by_var= source_table_nm= by_value=;
              call symput('BY_VALUE'||strip(put(i_by_value,best.)),strip(put(by_value,best.)));
           end;
            by_master_dsid=close(by_master_dsid);
        end;
        call symput('BY_VAR',strip(by_var));
        call symput('BY_VALUE_CNT',strip(put(i_by_value,best.)));
        
     run;

 

%do i_by_value=1 %to &by_value_cnt; 

%do isection=1 %to %ecm_nobs(&form_preview_config_table_nm);
    
    data _null_;
         set &form_preview_config_table_nm (obs=&isection);         
         template_nm=strip(preview_file_prefix)||strip(section_file_suffix);
         call symput('SOURCE_TABLE_NM',strip(source_table_nm));
         call symput('TEMPLATE_NM',strip(template_nm));
         call symput('PREVIEW_FILE_PREFIX',strip(preview_file_prefix));
    run;

    data by_source_table;
         set &source_table_nm;
         where &by_var = &i_by_value;
    run;
    
    /* The FDF program was generated by ecmrr_fdf_pgm_gen during configuration time  */
    /* It was generated based on the definition in form_preview_field_config  table */ 
    filename fdfpgm "&ecm_config_ucmacro_path&slash.&template_nm..sas" lrecl=8000;

       
    %do ipage=1 %to %ecm_nobs(by_source_table);

   /* increment the page counter */
    %let &last_page_no_mvar=%eval(&&&last_page_no_mvar+1);

    /* create an output fdf file for each page */
    filename outfn "%sysfunc(pathname(work))&slash.&preview_file_prefix._p&&&last_page_no_mvar...fdf";
    proc sql noprint; 
         insert into page_log values ("&preview_file_prefix._p&&&last_page_no_mvar...fdf",                                      
                                      "&template_nm..pdf",
                                      "&preview_file_prefix..pdf"); 
    quit;

    options missing=' ';
    data  _null_;
        set by_source_table (obs=&ipage);
                
        file outfn ls=256;
        length outline $256;
        length source_field_value $ 8000;
        z_page_txt="Page &last_page_no of &total_page_no";
         
        %inc fdfpgm ;           
     
     run;
     filename outfn clear;

     %end;
     filename fdfpgm clear;
    
    %end;
   
%end;

    

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;
MEXIT: 
%mend;
 
