
/***********************************************************************************/
/* Copyright (c) 2012, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_fdf_sar_driver                                             */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       driver program to generate sar fdf files                         */
/*                                                                                 */
/* PARAMETERS:                                                                     */
/*                rr_rk: key of the report to populate a fdf file (required)       */
/*                form_config_rk: key of the form (required)                       */
/* NOTE:          the fdf output is saved in the work directory                    */
/*                For testing:                                                     */
/*                To see the fdf in pdf form, copy the .pdf form to the work       */
/*                directory. Then click on the fdf file. Adobe reader is required. */
/***********************************************************************************/
%macro ecmrr_fdf_sar_driver(rr_rk=
                      ,form_config_rk=                      
                      );
%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

%local last_page_no total_page_no;

%let total_page_no=0;


proc sql noprint;
     create table form_preview_section_config as
     select a.*, b.preview_file_prefix 
     from ecm_db.form_preview_section_config as a,
          ecm_db.form_config as b
     where a.form_config_rk=&form_config_rk and
           a.form_config_rk=b.form_config_rk           
     order by section_order_no;
     quit;

/* break up the form_preview_section_config into pieces to handle looping by institutions and subjects  */
 

data section_config_rr_pre
     section_config_branch
     section_config_subject
     section_config_rr_post;

     set form_preview_section_config end=eof;

     retain post_flg 0 ;
     retain total_page_no 0;
     length by_var $ 32;       
     /* Obtain the # of records in each source table */
     /* It will be used for labelling the pages at the end of each page */
     src_dsid=open(source_table_nm);
     src_nobs=attrn(src_dsid,'NOBS');
     total_page_no+src_nobs;
     src_dsid=close(src_dsid);

     if index(source_table_nm,'BRANCH') then 
     do;
        post_flg=1;      
        by_var='Z_INSTITUTION_SEQ_NO';
        output section_config_branch;
     end;
     else if index(source_table_nm,'SUBJECT') then 
          do;
              /* this portion */
              by_var='Z_SUBJECT_SEQ_NO';
              post_flg=1;
              output section_config_subject;
          end; 
          else if post_flg then 
               do;
                   /* the portion is after institutions involveds and subjects */
                   by_var='Z_RR_SEQ_NO';
                   output section_config_rr_post;
               end;
               else 
               do;  
                    /* the portion is after institutions involveds and subjects */
                    by_var='Z_RR_SEQ_NO';
                    output section_config_rr_pre;
               end;
    drop src_dsid total_page_no;
    if eof then call symput('TOTAL_PAGE_NO',put(total_page_no,best.));

run;


data page_log;
     length fdf_nm template_nm output_nm $ 1024;
     stop;
run;

%let last_page_no=0;

/* generate the fdf files based on the definition in the section configration file */

%ecmrr_fdf_new_subdriver(form_preview_config_table_nm=section_config_rr_pre
                         ,last_page_no_mvar=last_page_no
                         ,total_page_no=&total_page_no
                         );

%ecmrr_fdf_new_subdriver(form_preview_config_table_nm=section_config_branch
                         ,last_page_no_mvar=last_page_no
                         ,total_page_no=&total_page_no
                         );


%ecmrr_fdf_new_subdriver(form_preview_config_table_nm=section_config_subject
                         ,last_page_no_mvar=last_page_no
                         ,total_page_no=&total_page_no
                         );

%ecmrr_fdf_new_subdriver(form_preview_config_table_nm=section_config_rr_post 
                         ,last_page_no_mvar=last_page_no
                         ,total_page_no=&total_page_no
                         );

/* Merge all the fdf files with the correct pdf templates and generate the final pdf */
%ecmrr_fdf_new_merger(page_log_table_nm=page_log);

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;
MEXIT: 
%mend;
 
