
/***********************************************************************************/
/* Copyright (c) 2012, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_fincen_concat_txt                                          */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       concatenate multiple the text strings into one long string.      */
/*                The text string can be formatted.                                */
/* PARAMETERS:    indsn: input table name                                          */
/*                outdsn: output table name                                        */
/*                byvar: by class variables  (optional)                            */
/*                invar: input code variable which will be concatenated            */
/*                outvar: output variable for concatenated codes                   */
/*                delimiter: character for separating the text strings             */
/*                maxsize:    maximum number of codes to be included               */
/*                sortedYN: is the input table sorted   (optional)                 */
/*                sortby: sort by variables   (optional)                           */
/*                fmtnm: name of the sas format for the display the text           */
/***********************************************************************************/
%macro ecmrr_fincen_concat_txt(indsn=
                            ,outdsn=
                            ,byvar=
                            ,invar=
                            ,outvar=
                            ,delimiter=
                            ,maxsize=
                            ,sortedYN=N
                            ,sortby=
                            ,fmtnm=
                           );

%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

/* Sort the data if it is not sorted */ 
%if &sortedYN = N and &sortby ne %then
%do;
   proc sort data=&indsn out=t_sorted_indsn;
        by &sortby;
   run;
   %let sorted_dsn=t_sorted_indsn;
%end;
%else %let sorted_dsn=&indsn;

/* get the last variable of the by variable list */
%if &byvar ne  %then %let last_byvar=%scan(&byvar,%sysfunc(countw(&byvar)));
%else %let last_byvar=;
    

/* concatentate the code and output one row per by group */
data &outdsn;
     set &sorted_dsn end=eof;
     length &outvar $&maxsize;
     retain &outvar _tmp_first_flg;
     drop _tmp_first_flg;
 
     %if &last_byvar ne %then
     %do;
         by &byvar;  
         if first.&last_byvar then 
     %end;
     %else 
     %do;
        if _n_=1 then 
		
     %end;

     do;
	     _tmp_first_flg=1;
         &outvar='';
               
     end;
	 else _tmp_first_flg=0;
     if not _tmp_first_flg then
     &outvar=strip(&outvar)||"&delimiter"||
     %if &fmtnm = %then
     %do;
             &invar
     %end;
     %else
     %do;
             put(&invar,&fmtnm..)
     %end;

     ;
	 else
	 &outvar=
	 %if &fmtnm = %then
     %do;
             &invar
     %end;
     %else
     %do;
             put(&invar,&fmtnm..)
     %end;
     ;
     %if &last_byvar ne %then
     %do;
          if last.&last_byvar then
     %end;
     %else
     %do;
          if eof  then

     %end;
          output;
      drop &invar ;
run;


%if &syserr > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;

%mExit:

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;



%mend;
