
/***********************************************************************************/
/* Copyright (c) 2011, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_fincen_narrative                                           */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       break up the long narrative into multiple rows                   */
/* PARAMETERS:    indsn: input table name                                          */
/*                outdsn: output table name                                        */
/*                byvar: by class variables  (optional)                            */
/*                invar: input string variable which will be broken up             */
/*                outvar: output variable name                                     */
/*                outsize:  output variable maximum length                         */
/*                outseqvar: output variable for row number                        */
/*                outseqmax: maximum row number                                    */
/* NOTE:          &invar._1 and &invar._2 must exist in &indsn                     */
/***********************************************************************************/

%macro ecmrr_fincen_narrative(indsn=
                            ,outdsn=
                            ,idvar=
                            ,invar=
                            ,outvar=
                            ,outsize=
                            ,outseqvar= 
                            ,outseqmax=99
                            );


%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

%if  %ecm_var_exist(&indsn,&invar._2)=1 %then %let more_invar=&invar._2;
%else %let more_invar=;
     
data &outdsn (keep= &idvar &outseqvar &outvar) ;     
     
     set &indsn (keep=&idvar &invar &more_invar) end=eof;
     where &invar > '';
	 /* remove non printable characters including carriage return */
	 &invar=compress(&invar,,'kw');
      start=1;
     len1 = length(&invar);
     %if &more_invar ne %then
     %do;
	 &invar._2=compress(&invar._2,,'kw');
     len2=length(&invar._2);
     %end;
     %else
     %do;
          &invar._2='';
          len2=0;
     %end;
   
   ivar=1;
   more_txt=1;
   &outseqvar=0; 
   curr_desc=&invar;
   len=lengthn(curr_desc);
   /* substr the first 32760 char field */
   link PARSE_DESC;
   /* substr the second 32760 char field */
   if len2 > 0 then  
        /* concatenate the rest of the first field including the trailing spaces with the second field  */
      curr_desc=substrn(&invar,start)||&invar._2;
     else 
       curr_desc=substrn(&invar,start);
    
   start=1;
   len=lengthn(curr_desc);
   if len > 0 then 
   do;
        ivar=2;
        more_txt=1;
        link PARSE_DESC;
   end;
   return;

  PARSE_DESC:
   do while (more_txt and &outseqvar < &outseqmax); 
      &outvar = substrn(curr_desc,start,&outsize);
      if &outvar ne ' ' and &outseqvar<= &outseqmax then
      do ;
           if len > &outsize then
             explain_desc_len = &outsize;
           else
             explain_desc_len = len;
            
           if not (ivar=1 and (len - &outsize) <0) then
           do;
              /* output the data when there are more text for the same source string */
              /* or there is no more data for the next source string                 */
              /* otherwise, save the string for the next line                        */
              &outseqvar + 1;
              output;
              start+&outsize;
              len = len - &outsize;
              if len <= 0 then more_txt=0;
            end;
            else more_txt=0;
      end;
      
    end;

   run;

%if &syserr > 4 %then 
%do;
     %let successYN=N;
     %put %sysfunc(sasmsg(&smdds,GEN_STP_ABORT,NOQUOTE,&sysmacroname)) ;
     %goto mExit;
%end;
%mEXIT:
%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;


%mend;  
/*
%ecmrr_fincen_narrative(indsn=rr_pivot
                            ,outdsn=z_explanation
                            ,idvar=rr_rk 
                            ,invar=X_ACTIVITY_DESC_LONG_TXT
                            ,outvar=Z_EXPLANATION
                            ,outseqvar=ROW_NO 
                            ,outsize=396
                            ,outseqmax=99
                            );
*/
