/***********************************************************************************/
/* Copyright (c) 2012, SAS Institute Inc., Cary, NC, USA, All Rights Reserved      */
/*                                                                                 */
/* NAME:          ecmrr_prvw_fincen_newctr_data                                    */
/* PRODUCT:       Enterprise Case Management                                       */
/* PURPOSE:       Transform the RR data for report preview                         */
/* PARAMETERS:                                                                     */
/*                rr_config_rk: key of the report to preview (required)            */
/* NOTE:                                                                           */
/***********************************************************************************/
%macro ecmrr_prvw_fincen_newctr_data(rr_rk=, form_config_rk=202);


%put %sysfunc(sasmsg(&smdds,GEN_MAC_START_NOTE,NOQUOTE,&sysmacroname)) ;

/***************************************************/
/* Macro for tranposing foreign cash transactions  */
/* input parameters:                               */
/*    outdsn - Output data set name                */
/*    array_size - # of records to transpose       */
/*    in_out - In for cash in and Out for cash out */
/*    where_stmt - where clause to filter the input*/
/*                 data                            */
/* Note: input table is R_X_FOREIGN_CASH_IN or     */
/*       R_X_FOREIGN_CASH_OUT depending on the     */
/*       value of IN_OUT                           */
/***************************************************/
%macro ecmrr_foreign_trans(outdsn=
                           ,array_size=
                           ,in_out=
                           ,where_stmt=
                            );
   

data &outdsn;
     set r_x_foreign_cash_&in_out end=eof;
%if %str(&where_stmt) ne %str() %then
%do;
    where &where_stmt;
%end; 
    
     array zx_foreign_cash_&in_out._amt {&array_size} 8 
            zx_foreign_cash_&in_out._amt_1 - zx_foreign_cash_&in_out._amt_&array_size;
     array zx_foreign_cash_&in_out._country {&array_size} $ 2 
           zx_foreign_cash_&in_out._country_1 - zx_foreign_cash_&in_out._country_&array_size;
  
    
     retain zx_foreign_cash_&in_out._amt_1 - zx_foreign_cash_&in_out._amt_&array_size
            zx_foreign_cash_&in_out._country_1 - zx_foreign_cash_&in_out._country_&array_size
     ;
     z_rr_seq_no=1;
     if _n_=1  then link ARRAY_CLEAR;
     array_i+1;
     if array_i > &array_size then
     do;
         output;
         link ARRAY_CLEAR;
         array_i=1;
     end;
     link ARRAY_ASSIGN;
     if eof and (zx_foreign_cash_&in_out._amt_1 > . 
                 or zx_foreign_cash_&in_out._country_1 > '') then output;
     return;
     drop array_i;

ARRAY_CLEAR:
    do array_i=1 to &array_size;
       zx_foreign_cash_&in_out._amt{array_i}=.;
       zx_foreign_cash_&in_out._country{array_i}=' ';
      
    end;
    array_i=0;
return;

ARRAY_ASSIGN:

       zx_foreign_cash_&in_out._amt{array_i}=x_foreign_cash_&in_out._amt;
       zx_foreign_cash_&in_out._country{array_i}=x_foreign_cash_&in_out._country_cd;
       
return;

run;

%mend;



%let successYN=Y;
data rr_subset;
     rr_rk=&rr_rk;
run;


/* transform the data to rectangular structure */
 %ecm_create_label_fmt; 
 %if &successYN=N %then %goto mEXIT;

%let table_wh="X_FOREIGN_CASH_IN" "X_FOREIGN_CASH_OUT" "X_INSTITUTION" 
 "RR" "X_ACCOUNT_CASH_IN" "X_ACCOUNT_CASH_OUT" "X_PERSON_INVOLVED" "X_TRAN_METHOD"
;
%ecm_pivot_datatype(datatype=rr,in_lib=ECM_DB,out_lib=WORK,subset_dsn=rr_subset,table_wh=&table_wh);

 %if &successYN=N %then %goto mEXIT;


%ecmrr_fincen_new_sas_format(form_config_rk=&form_config_rk);
    
/**********************************/ 
/* Prepare Part I Person Involved */
/**********************************/

/* concatenate cash in accounts by subjects */
%ecmrr_fincen_concat_txt(indsn=r_x_account_cash_in
                            ,outdsn=t_zx_account_cash_in
                            ,byvar=x_person_involved_rk
                            ,invar=x_cash_in_acct_id
                            ,outvar=zx_cash_in_acct_id
                            ,delimiter=%str(, )
                            ,maxsize=32760
                            ,sortedYN=N
                            ,sortby=x_person_involved_rk row_no
                            ,fmtnm=
                           );

%ecmrr_fincen_concat_txt(indsn=r_x_account_cash_out
                            ,outdsn=t_zx_account_cash_out
                            ,byvar=x_person_involved_rk
                            ,invar=x_cash_out_acct_id
                            ,outvar=zx_cash_out_acct_id
                            ,delimiter=%str(, )
                            ,maxsize=32760
                            ,sortedYN=N
                            ,sortby=x_person_involved_rk row_no
                            ,fmtnm=
                           );
%let z_subject_cnt=%ecm_nobs(r_x_person_involved);

proc sql;
     create table zx_person_involved as
     select a.*
           , 1 as z_rr_seq_no
           , b.zx_cash_in_acct_id
           , b.zx_cash_out_acct_id
           , 'Part I Person Involved in Transaction '
                  ||strip(put(a.z_subject_seq_no,best.))
                  || " of &z_subject_cnt" as z_header_txt
     from r_x_person_involved (rename=(row_no=z_subject_seq_no)) as a
     left join (select coalesce(c.x_person_involved_rk, d.x_person_involved_rk) 
                       as x_person_involved_rk
                       , c.zx_cash_in_acct_id
                       , d.zx_cash_out_acct_id
                from t_zx_account_cash_in as c
                full join t_zx_account_cash_out as d
                on c.x_person_involved_rk=d.x_person_involved_rk
               ) as b
     on a.x_person_involved_rk=b.x_person_involved_rk
     order by z_subject_seq_no
     ;
quit;
/****************************************************/
/* Prepare Part II  Amount and Type of Transactions */
/****************************************************/
 


%ecmrr_fincen_concat_cd(indsn=r_x_tran_method
                            ,outdsn=t_zx_tran_method
                            ,byvar=rr_rk
                            ,invar=x_tran_method_type_cd
                            ,outvar=zx_tran_method_type
                            ,maxsize=5);
 
%ecmrr_foreign_trans(outdsn=t_zx_foreign_cash_in_3
                     ,array_size=3
                     ,in_out=in
                     ,where_stmt=%nrbquote(row_no <= 3)
                     );
%ecmrr_foreign_trans(outdsn=zx_foreign_cash_in
                     ,array_size=20
                     ,in_out=in
                      ,where_stmt=%nrbquote(row_no > 3)
                     );
%ecmrr_foreign_trans(outdsn=t_zx_foreign_cash_out_3
                     ,array_size=3
                     ,in_out=out
                     ,where_stmt=%nrbquote(row_no <= 3)                    
                     );
%ecmrr_foreign_trans(outdsn=zx_foreign_cash_out
                     ,array_size=20
                     ,in_out=out
                     ,where_stmt=%nrbquote(row_no > 3)
                      
                     );
data zx_rr;
     merge rr_pivot
           t_zx_tran_method
           t_zx_foreign_cash_in_3
           t_zx_foreign_cash_out_3
           ;
     if x_filed_dt=. then x_filed_dt=today();
     z_rr_seq_no=1;
run;
/**************************************************************************/
/* Prepare Part III Financial Institution Where Transaction(s) Take Place */
/**************************************************************************/

%let z_institution_cnt=%ecm_nobs(r_x_institution);


data zx_inst zx_inst_more;
     merge r_x_institution (rename=(row_no=z_inst_seq_no))
           zx_rr
     ;
     by rr_rk;
     z_rr_seq_no=1;
     z_header_txt='Part III Financial Institution Transactions(s) Takes Place '
                  ||strip(put(z_inst_seq_no,best.))||
                  " of &z_institution_cnt"
                  ;
     if _n_=1 then output zx_inst;
     else output zx_inst_more;
run;

%mExit:

%put %sysfunc(sasmsg(&smdds,GEN_MAC_END_NOTE,NOQUOTE,&sysmacroname)) ;

%mend;
